@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -56,7 +56,7 @@ class TLP_SCOPE AbstractProperty : public Tprop {
   friend class GraphView;
 
 public:
-  AbstractProperty(Graph *, std::string n = "");
+  AbstractProperty(Graph *, const std::string& n = "");
 
   /**
    * @brief Gets the default node value of the property.
@@ -418,10 +418,17 @@ protected:
   typename Tedge::RealType edgeDefaultValue;
 };
 
-template <typename vectType,typename eltType,typename propType=PropertyInterface>
+template <typename vectType,typename eltType,typename propType=VectorPropertyInterface>
 class TLP_SCOPE AbstractVectorProperty : public AbstractProperty<vectType, vectType, propType> {
 public:
-  AbstractVectorProperty(Graph *, std::string name = "");
+  AbstractVectorProperty(Graph *, const std::string& name = "");
+
+  // 2 methods inherited from VectorPropertyInterface
+  bool setNodeStringValueAsVector(const node, const std::string&,
+                                  char, char, char);
+
+  bool setEdgeStringValueAsVector(const edge, const std::string&,
+                                  char, char, char);
 
   /**
    * @brief Sets the value for node n, at index i, to v, and notify the observers of a modification.
