@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -64,7 +64,7 @@ TLP_SCOPE Graph * loadGraph(const std::string &filename, tlp::PluginProgress* pr
 
 /**
  * @ingroup Graph
- * @brief Saves the corresponding root graph and all its subgraphs to a file using the tlp format. Extension of the file can be either .tlp (human-readable text file) or .tlp.gz (gzipped text file).
+ * @brief Saves the corresponding graph and all its subgraphs to a file using the tlp format. Extension of the file can be either .tlp (human-readable text file) or .tlp.gz (gzipped text file).
  *
  * This function checks the file name for the '.gz' extension and uses a compressed output if found.
  *
@@ -118,30 +118,6 @@ TLP_SCOPE Graph* importGraph(const std::string &format, DataSet &dataSet, Plugin
  **/
 TLP_SCOPE Graph* newGraph();
 
-/**
- * @ingroup Graph
- * @brief Creates and returns an empty subgraph of the given graph.
- *
- * @deprecated this function should not be used anymore, please use Graph::addSubGraph() instead.
- *
- * @param graph The graph to add an empty subgraph to.
- * @param name The name of the new subgraph. Defaults to "unnamed".
- * @return :Graph* The newly created subgraph.
- **/
-TLP_SCOPE _DEPRECATED Graph* newSubGraph(Graph *graph, std::string name = "unnamed");
-
-/**
- * @ingroup Graph
- * @brief Creates and returns a subgraph of the graph that is equal to root (a clone subgraph).
- *
- * @deprecated this function should not be used anymore, please use Graph::addCloneSubGraph() instead.
- *
- * @param graph The Graph on which to create a clone subgraph.
- * @param name The name of the newly created subgraph. Defaults to "unnamed".
- * @return :Graph* The newly created clone subgraph.
- **/
-TLP_SCOPE _DEPRECATED Graph* newCloneSubGraph(Graph *graph, std::string name = "unnamed");
-
 /**
  * @ingroup Graph
  * Appends the selected part of the graph inG (properties, nodes and edges) into the graph outG.
@@ -159,6 +135,15 @@ TLP_SCOPE void copyToGraph(Graph *outG, const Graph *inG, BooleanProperty* inSel
  */
 TLP_SCOPE void removeFromGraph(Graph * ioG, BooleanProperty* inSelection=NULL);
 
+
+/**
+ * @ingroup Graph
+ * Gets an iterator over the root graphs. That is all the currently existing graphs which have been created using the tlp::newGraph, tlp::loadGraph or tlp::importGraph functions and are the root graphs of an existing graph hierarchy.
+ * @return An iterator over all the root graphs. The caller of this function is responsible of the deletion of the returned iterator.
+ */
+TLP_SCOPE Iterator<Graph*>* getRootGraphs();
+
+
 /**
  * @ingroup Graph
  * The class Graph is the interface of a Graph in the Tulip Library.
@@ -266,7 +251,7 @@ public:
     * @return :Graph* The newly created subgraph.
     **/
   virtual Graph *addSubGraph(BooleanProperty *selection=NULL,
-                             std::string name = "unnamed")=0;
+                             const std::string& name = "unnamed")=0;
 
   /**
    * @brief Creates and returns a new named sub-graph of this graph.
@@ -274,7 +259,7 @@ public:
    * @param name The name of the newly created subgraph.
    * @return :Graph* The newly created subgraph.
    **/
-  Graph *addSubGraph(std::string name);
+  Graph *addSubGraph(const std::string& name);
 
   /**
    * @brief Creates and returns a subgraph that contains all the elements of this graph.
@@ -283,7 +268,7 @@ public:
    * @param addSibling if true the clone subgraph will be a sibling of this graph, if false (the default) it will be a subgraph of this graph
    * @return :Graph* The newly created clone subgraph. NULL will be returned if addSibling is set to true and this graph is a root graph.
    **/
-  virtual Graph* addCloneSubGraph(std::string name = "unnamed", bool addSibling = false);
+  virtual Graph* addCloneSubGraph(const std::string& name = "unnamed", bool addSibling = false);
 
   /**
    * @brief Creates and returns a new sub-graph of the graph induced by a set of nodes.
@@ -360,8 +345,8 @@ public:
   virtual void setSuperGraph(Graph *)=0;
 
   /**
-   * @brief Gets an iterator on all the sub-graphs of the graph.
-   * For instance, in the followong graph hierarchy:
+   * @brief Gets an iterator over all the sub-graphs of the graph.
+   * For instance, in the following graph hierarchy:
    ** root
    * / \
    * A  B
@@ -397,7 +382,7 @@ public:
 
   /**
    * @brief Return the number of direct sub-graphs.
-   * For instance, in the followong graph hierarchy:
+   * For instance, in the following graph hierarchy:
    * root
    * / \
    * A  B
@@ -413,7 +398,7 @@ public:
 
   /**
    * @brief Return the number of descendant sub-graphs.
-   * For instance, in the followong graph hierarchy:
+   * For instance, in the following graph hierarchy:
    * root
    * / \
    * A  B
@@ -478,6 +463,22 @@ public:
    * @see getSubGraph(const std::string &) to search only in direct subgraphs.
    */
   virtual Graph* getDescendantGraph(const std::string &name) const=0;
+
+  /**
+   * @brief Gets an iterator over all the descendant sub-graphs of the graph.
+   * For instance, in the following graph hierarchy:
+   ** root
+   * / \
+   * A  B
+   *    /|\
+   *   C D E
+   *
+   * @codeline root->getSubGraphs(); @endcode
+   * Will return an iterator over A B, C, D and E.
+   * @return An iterator over this graph's descendant subgraphs.
+   */
+  Iterator<Graph *> * getDescendantGraphs() const;
+
   //==============================================================================
   // Modification of the graph structure
   //==============================================================================
@@ -1252,17 +1253,6 @@ public:
                               std::string &errorMessage,
                               PluginProgress *progress=NULL,
                               DataSet *parameters=NULL);
-  /**
-   * @cond DOXYGEN_HIDDEN
-   *
-   * @deprecated Use applyPropertyAlgorithm() instead.
-   *
-   * @endcond
-   */
-  template<typename PropertyType>
-  _DEPRECATED bool computeProperty(const std::string &algorithm,
-                                   PropertyType* result, std::string &msg,
-                                   PluginProgress *progress=NULL, DataSet *data=NULL);
 
   // updates management
   /**
