@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -115,7 +115,7 @@ public:
    * @brief Gets a string describing the type of the property (e.g. "graph", "double", "layout", "string", "integer", "color", "size").
    * @return The name of this property's type.
    */
-  virtual std::string getTypename() const = 0;
+  virtual const std::string& getTypename() const = 0;
 
   /**
    * @brief Gets the name of the property (e.g. viewLayout).
@@ -466,6 +466,40 @@ protected:
   void notifyRename(const std::string& newName);
 };
 
+/**
+ * @ingroup Graph
+ * @brief VectorPropertyInterface describes the interface of a graph property whose holded value is a vector (std::vector)
+ *
+ */
+class TLP_SCOPE VectorPropertyInterface: public PropertyInterface {
+public:
+  VectorPropertyInterface(): PropertyInterface() {}
+
+  ~VectorPropertyInterface() {}
+
+  /**
+   * @brief Sets a new vector described by the string parameter as the node value.
+   * @param n The node on which to set the new value.
+   * @param value A string listing the elements of the vector to set on the node.
+   * @param openChar an optional character opening the list of elements. Default value is '('; when set to '\0' it indicates that there is no opening character.
+   * @param sepChar an optional character separing the elements of the list. Default value is ','.
+   * @param closeChar an optional character closing the list of elements. Default value is ')'; when set to '\0' it indicates that there is no opening character.
+   * @return Whether the string was a correct representation for this property's type. If not, the value is not set.
+   */
+  virtual bool setNodeStringValueAsVector(const node n, const std::string & value, char openChar = '(', char sepChar = ',', char closeChar = ')') = 0;
+
+  /**
+   * @brief Sets a new vector described by the string parameter as the edge value.
+   * @param e The edge on which to set value on.
+   * @param value A string listing the elements of the vector to set on the edge.
+   * @param openChar an optional character opening the list of elements. Default value is '('; when set to '\0' it indicates that there is no opening character.
+   * @param sepChar an optional character separing the elements of the list. Default value is ','.
+   * @param closeChar an optional character closing the list of elements. Default value is ')'; when set to '\0' it indicates that there is no opening character.
+   * @return Whether the string was a correct representation for this property's type. If not, the value is not set.
+   */
+  virtual bool setEdgeStringValueAsVector(const edge e, const std::string & value, char openChar = '(', char sepChar = ',', char closeChar = ')') = 0;
+};
+
 /**
  * @ingroup Observation
  * @brief Contains additional information about events on a property,
