@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -19,6 +19,7 @@
 
 #include <iomanip>
 #include <fstream>
+#include <stack>
 
 #include <tulip/ForEach.h>
 #include <tulip/StlIterator.h>
@@ -210,14 +211,6 @@ Graph * tlp::newGraph() {
   return g;
 }
 //=========================================================
-Graph * tlp::newSubGraph(Graph *graph, std::string name) {
-  return graph->addSubGraph(NULL, name);
-}
-//=========================================================
-Graph * tlp::newCloneSubGraph(Graph *graph, std::string name) {
-  return graph->addCloneSubGraph(name);
-}
-//=========================================================
 Graph * tlp::loadGraph(const std::string &filename, PluginProgress *progress) {
   DataSet dataSet;
   std::string algName = "TLP Import";
@@ -234,9 +227,9 @@ bool tlp::saveGraph(Graph* graph, const std::string& filename, PluginProgress *p
   ostream *os;
 
   if (filename.rfind(".gz") == (filename.length() - 3))
-    os =  tlp::getOgzstream(filename.c_str());
+    os =  tlp::getOgzstream(filename);
   else
-    os = new ofstream(filename.c_str());
+    os = tlp::getOutputFileStream(filename);
 
   bool result;
   DataSet data;
@@ -495,6 +488,49 @@ void tlp::copyToGraph (Graph *outG, const Graph* inG,
   delete edgeIt;
 }
 
+// define a class of Iterator to iterate the root graphs
+class RootGraphsIterator :public tlp::Iterator<tlp::Graph *> {
+  std::vector<Graph *> roots;
+  Iterator<Graph *>* rootsIterator;
+
+public:
+  RootGraphsIterator() {
+    const VectorGraph& ovg = tlp::Observable::getObservableGraph();
+
+    // we iterate the observable graph nodes
+    node n;
+    Graph* g;
+    forEach(n, ovg.getNodes()) {
+      if (tlp::Observable::isAlive(n) &&
+          (g = dynamic_cast<Graph*>(tlp::Observable::getObject(n)))) {
+        // check if g is a root graph
+        if (g->getRoot() == g)
+          roots.push_back(g);
+      }
+    }
+
+    rootsIterator =
+      new StlIterator<Graph*, std::vector<tlp::Graph*>::iterator>(roots.begin(),
+          roots.end());
+  }
+
+  ~RootGraphsIterator() {
+    delete rootsIterator;
+  }
+
+  Graph* next() {
+    return rootsIterator->next();
+  }
+
+  bool hasNext() {
+    return rootsIterator->hasNext();
+  }
+};
+
+Iterator<Graph*>* tlp::getRootGraphs() {
+  return new RootGraphsIterator();
+}
+
 bool Graph::applyAlgorithm(const std::string &algorithm,
                            std::string &errorMessage,
                            DataSet *dataSet, PluginProgress *progress) {
@@ -1025,12 +1061,12 @@ void updatePropertiesUngroup(Graph *graph, node metanode,
   }
 }
 //=========================================================
-Graph* Graph::addSubGraph(std::string name) {
+Graph* Graph::addSubGraph(const std::string& name) {
   Graph* g = addSubGraph(NULL, name);
   return g;
 }
 //=========================================================
-Graph* Graph::addCloneSubGraph(std::string name, bool addSibling) {
+Graph* Graph::addCloneSubGraph(const std::string& name, bool addSibling) {
   BooleanProperty selection(this);
   selection.setAllNodeValue(true);
   selection.setAllEdgeValue(true);
@@ -1659,3 +1695,72 @@ void Graph::delEdges(const std::vector<edge>& edges, bool deleteInAllGraphs) {
   StlIterator<edge, vector<edge>::const_iterator> vIterator(edges.begin(), edges.end());
   delEdges(&vIterator, deleteInAllGraphs);
 }
+
+struct DescendantGraphsIterator :public Iterator<Graph*> {
+  // use a stack to store non empty iterators
+  stack<Iterator<Graph *>*> iterators;
+  // the current one
+  Iterator<Graph *>* current;
+
+  DescendantGraphsIterator(const Graph *g) {
+    current = g->getSubGraphs();
+
+    if (!current->hasNext()) {
+      delete current;
+      current = NULL;
+    }
+  }
+
+  ~DescendantGraphsIterator() {
+    if (current)
+      delete current;
+
+    while(!iterators.empty()) {
+      delete iterators.top();
+      iterators.pop();
+    }
+  }
+
+  bool hasNext() {
+    return current != NULL;
+  }
+
+  Graph* next() {
+    if (current) {
+      Graph* g = current->next();
+      Iterator<Graph *>* itg = g->getSubGraphs();
+
+      if (itg->hasNext()) {
+        if (current->hasNext())
+          // pushed iterators are always non empty
+          iterators.push(current);
+        else
+          delete current;
+
+        current = itg;
+      }
+      else {
+        delete itg;
+
+        if (!current->hasNext()) {
+          delete current;
+
+          if (!iterators.empty()) {
+            current = iterators.top();
+            iterators.pop();
+          }
+          else
+            current = NULL;
+        }
+      }
+
+      return g;
+    }
+
+    return NULL;
+  }
+};
+
+Iterator<Graph*>* Graph::getDescendantGraphs() const {
+  return new DescendantGraphsIterator(this);
+}
