@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -89,7 +89,7 @@ void GraphAbstract::setSubGraphToKeep(Graph* sg) {
 }
 //=========================================================================
 Graph *GraphAbstract::addSubGraph(unsigned int id, BooleanProperty *selection,
-                                  std::string name) {
+                                  const std::string& name) {
   Graph *tmp = new GraphView(this, selection, id);
 
   if (!name.empty())
@@ -102,7 +102,7 @@ Graph *GraphAbstract::addSubGraph(unsigned int id, BooleanProperty *selection,
 }
 //=========================================================================
 Graph *GraphAbstract::addSubGraph(BooleanProperty *selection,
-                                  std::string name) {
+                                  const std::string& name) {
   return addSubGraph(0, selection, name);
 }
 //=========================================================================
