@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -20,6 +20,15 @@
 
 using namespace tlp;
 
+GraphDecorator::GraphDecorator(Graph* s):graph_component(s) {
+  assert(s);
+}
+
+GraphDecorator::~GraphDecorator() {
+  notifyDestroy();
+}
+
+
 //============================================================
 void GraphDecorator::clear() {
   graph_component->clear();
@@ -27,7 +36,7 @@ void GraphDecorator::clear() {
 
 //============================================================
 Graph *GraphDecorator::addSubGraph(BooleanProperty *selection,
-                                   std::string name) {
+                                   const std::string& name) {
   Graph* sg = graph_component->addSubGraph(selection, name);
   notifyBeforeAddSubGraph(sg);
   notifyAfterAddSubGraph(sg);
@@ -80,6 +89,19 @@ Graph* GraphDecorator::getSuperGraph()const {
   return graph_component->getSuperGraph();
 }
 
+//============================================================
+node GraphDecorator::createMetaNode(const std::set<node> &nodeSet, bool multiEdges, bool delAllEdge) {
+  return graph_component->createMetaNode(nodeSet, multiEdges, delAllEdge);
+}
+
+void GraphDecorator::createMetaNodes(Iterator<Graph *> *itS, Graph *quotientGraph, std::vector<node>& metaNodes) {
+  graph_component->createMetaNodes(itS, quotientGraph, metaNodes);
+}
+
+node GraphDecorator::createMetaNode(Graph* subGraph, bool multiEdges, bool delAllEdge) {
+  return graph_component->createMetaNode(subGraph, multiEdges, delAllEdge);
+}
+
 //============================================================
 void GraphDecorator::setSuperGraph(Graph* s) {
   graph_component->setSuperGraph(s);
