@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -19,6 +19,7 @@
 
 #include <tulip/PropertyTypes.h>
 #include <tulip/Graph.h>
+#include <tulip/StringCollection.h>
 
 #include <stdint.h>
 
@@ -108,6 +109,8 @@ bool EdgeSetType::read(istream& is, RealType & v) {
     if( !(is >> c) )
       return false;
 
+    if (isspace(c)) continue;
+
     if( c == ')' )
       return true;
 
@@ -247,7 +250,7 @@ void BooleanType::write(ostream& os, const RealType &v) {
     os << "false";
 }
 
-bool BooleanType::read(istream& is, RealType & v) {
+bool BooleanType::read(istream& is, RealType & v, bool untilEnd) {
   char c = ' ';
 
   while((is >> c) && isspace(c)) {}
@@ -285,9 +288,26 @@ bool BooleanType::read(istream& is, RealType & v) {
       return false;
   }
 
+  if (untilEnd) {
+    // check if there is only space char until the end
+    for(;;) {
+      if( !(is >> c) )
+        return true;
+
+      if (!isspace(c))
+        return false;
+    }
+  }
+
   return true;
 }
 
+bool BooleanType::fromString(RealType &v, const std::string &s,
+                             bool untilEnd) {
+  std::istringstream iss(s);
+  return read(iss, v, untilEnd);
+}
+
 // BooleanVectorType
 void BooleanVectorType::write(ostream& os, const RealType & v) {
   os << '(';
@@ -320,30 +340,35 @@ void BooleanVectorType::writeb(ostream& oss, const RealType & v) {
   oss.write(vc.data(), vSize);
 }
 
-bool BooleanVectorType::read(istream& is,  RealType & v) {
+bool BooleanVectorType::read(istream& is,  RealType & v, char openChar,
+                             char sepChar, char closeChar) {
   v.clear();
 
   char c =' ';
   bool firstVal = true;
 
-  // go to first '('
+  // go to first non space char
   while((is >> c) && isspace(c)) {}
 
-  if (c != '(')
-    return false;
+  if (openChar) {
+    if (c != openChar)
+      return false;
+  }
+  else
+    is.unget();
 
   for(;;) {
     if( !(is >> c) )
-      return false;
+      return !closeChar;
 
     if (isspace(c))
       continue;
 
-    if(c == ')') {
+    if(c == closeChar) {
       return true;
     }
 
-    if (c == ',') {
+    if (c == sepChar) {
       if (firstVal)
         return false;
     }
@@ -384,15 +409,15 @@ bool BooleanVectorType::readb(istream& iss, RealType & v) {
 }
 
 // LineType
-bool LineType::read(istream& is, RealType& v) {
+bool LineType::read(istream& is, RealType& v, char openChar,
+                    char sepChar, char closeChar) {
   v.clear();
 
   char c =' ';
   bool firstVal = true;
   bool dbqFound = false;
 
-  // go to first '('
-  // skip space chars
+  // go to first non space char
   while((is >> c) && isspace(c)) {}
 
   // value may have been enclosed by double quotes
@@ -404,17 +429,21 @@ bool LineType::read(istream& is, RealType& v) {
     while((is >> c) && isspace(c)) {}
   }
 
-  if (c != '(')
-    return false;
+  if (openChar) {
+    if (c != openChar)
+      return false;
+  }
+  else
+    is.unget();
 
   for(;;) {
     if( !(is >> c) )
-      return false;
+      return !closeChar;
 
     if (isspace(c))
       continue;
 
-    if(c == ')') {
+    if(c == closeChar) {
       if (dbqFound) {
         // expect it is the next non space char
         while((is >> c) && isspace(c)) {}
@@ -423,10 +452,10 @@ bool LineType::read(istream& is, RealType& v) {
           return false;
       }
 
-      return true;
+      return openChar;
     }
 
-    if (c == ',') {
+    if (c == sepChar) {
       if (firstVal)
         return false;
 
@@ -549,8 +578,9 @@ string StringType::defaultValue() {
   return string("");
 }
 
-void StringType::write(ostream& os, const RealType & v ) {
-  os << '"';
+void StringType::write(ostream& os, const RealType & v, char openCloseChar) {
+  if (openCloseChar)
+    os << openCloseChar;
 
   for(char* str = (char *) v.c_str(); *str; ++str) {
     char c = *str;
@@ -561,7 +591,8 @@ void StringType::write(ostream& os, const RealType & v ) {
     os << c;
   }
 
-  os << '"';
+  if (openCloseChar)
+    os << openCloseChar;
 }
 
 void StringType::writeb(ostream& os, const RealType & str) {
@@ -577,21 +608,33 @@ string StringType::toString( const RealType & v ) {
   return v;
 }
 
-bool StringType::read(istream& is, RealType & v) {
+bool StringType::read(istream& is, RealType & v, char openChar,
+                      char closeChar) {
   char c= ' ';
 
-  // go to first '"'
+  // go to first non space char
   while((is >> c) && isspace(c)) {}
 
-  if (c != '"')
+  // ensure space chars are not skipped
+  // in the string to extract
+  is.unsetf(ios_base::skipws);
+
+  if (openChar && c != openChar)
     return false;
 
+  if (!openChar)
+    is.unget();
+
   bool bslashFound = false;
   string str;
 
   for(;;) {
-    if ( !(is >> c) )
+    if ( !(is >> c) ) {
+      if (!openChar || !closeChar)
+        break;
+
       return false;
+    }
 
     if (bslashFound) {
       str.push_back(c);
@@ -601,7 +644,7 @@ bool StringType::read(istream& is, RealType & v) {
       if (c == '\\')
         bslashFound = true;
       else {
-        if (c == '"')
+        if (closeChar && c == closeChar)
           break;
 
         str.push_back(c);
@@ -609,6 +652,12 @@ bool StringType::read(istream& is, RealType & v) {
     }
   }
 
+  // remove trailing space chars
+  std::size_t found = str.find_last_not_of(" \t\f\v\n\r");
+
+  if (found != std::string::npos)
+    str.erase(found+1);
+
   v = str;
   return true;
 }
@@ -654,15 +703,20 @@ void StringVectorType::writeb(ostream& os, const RealType & v) {
     StringType::writeb(os, v[i]);
 }
 
-bool StringVectorType::read(istream& is, RealType & v) {
+bool StringVectorType::read(istream& is, RealType & v, char openChar,
+                            char sepChar, char closeChar) {
   v.clear();
   char c = ' ';
 
-  // go to first '('
+  // go to first non space char
   while((is >> c) && isspace(c)) {}
 
-  if (c != '(')
-    return false;
+  if (openChar) {
+    if (c != openChar)
+      return false;
+  }
+  else
+    is.unget();
 
   is.unsetf(ios_base::skipws);
   bool firstVal = true;
@@ -670,33 +724,39 @@ bool StringVectorType::read(istream& is, RealType & v) {
 
   for( ;; ) {
     if( !(is >> c) )
-      return false;
+      return (!sepFound && !closeChar);
 
     if (isspace(c))
       continue;
 
-    if( c == ')' ) {
-      if (sepFound)
+    if( c == closeChar) {
+      if (!closeChar || sepFound)
         return false;
 
       return true;
     }
 
-    if (c == ',') {
+    if (c == sepChar) {
       if (sepFound)
         return false;
 
       sepFound = true;
     }
     else {
-      if ((firstVal || sepFound) && c == '"') {
+      if ((firstVal || sepFound) && (!openChar || c == '"')) {
         string str;
         is.unget();
 
-        if (!StringType::read(is, str))
+        if (!(openChar ? StringType::read(is, str) :
+              StringType::read(is, str, '\0', sepChar)))
           return false;
 
         v.push_back(str);
+
+        if (!openChar)
+          // last read char was sepChar
+          is.unget();
+
         firstVal = false;
         sepFound = false;
       }
@@ -711,7 +771,7 @@ bool StringVectorType::readb(istream& iss, RealType & v) {
   unsigned int size;
 
   if (!bool(iss.read((char *) &size, sizeof(size))))
-    return size;
+    return false;
 
   v.resize(size);
 
@@ -918,6 +978,74 @@ struct EdgeVectorTypeSerializer : public TypedDataSerializer<vector<edge> > {
 
 };
 
+struct StringCollectionSerializer :public TypedDataSerializer<StringCollection> {
+  StringCollectionSerializer():TypedDataSerializer<StringCollection>("StringCollection") {}
+
+  DataTypeSerializer* clone() const {
+    return new StringCollectionSerializer();
+  }
+
+  void write(ostream& os, const StringCollection& sc) {
+    os << '"';
+    std::vector<std::string> values = sc.getValues();
+
+    for(unsigned int i = 0; i < values.size(); ++i) {
+      if (i)
+        os << ';';
+
+      StringType::write(os, values[i], 0);
+    }
+
+    os << '"';
+  }
+
+  bool read(istream& is, StringCollection& sc) {
+    char c = ' ';
+
+    // go to first '"'
+    while((is >> c) && isspace(c)) {}
+
+    if (c != '"')
+      return false;
+
+    string str;
+
+    for( ;; ) {
+      if( !(is >> c) )
+        return false;
+
+      if( c == '"' ) {
+        sc.push_back(str);
+        return true;
+      }
+
+      if (c == ';') {
+        sc.push_back(str);
+        str.clear();
+      }
+      else
+        str.push_back(c);
+    }
+  }
+
+  bool setData(tlp::DataSet& dts, const string& prop, const string& val) {
+    StringCollection col;
+
+    string::size_type lastPos = val.find_first_not_of(";");
+    string::size_type pos = val.find_first_of(";", lastPos);
+
+    while (string::npos != pos || string::npos != lastPos) {
+      col.push_back(val.substr(lastPos, pos - lastPos));
+      lastPos = val.find_first_not_of(";", pos);
+      pos = val.find_first_of(";", lastPos);
+    }
+
+    dts.set(prop, col);
+
+    return true;
+  }
+};
+
 void tlp::initTypeSerializers() {
   DataSet::registerDataTypeSerializer<EdgeSetType::RealType>(KnownTypeSerializer<EdgeSetType>("edgeset"));
 
@@ -961,4 +1089,6 @@ void tlp::initTypeSerializers() {
 
   DataSet::registerDataTypeSerializer<vector<edge> >(EdgeVectorTypeSerializer());
 
+  DataSet::registerDataTypeSerializer<StringCollection>(StringCollectionSerializer());
+
 }
