@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -20,7 +20,6 @@
 #include <string>
 #include <vector>
 #include <errno.h>
-#include <sys/stat.h>
 
 #include <tulip/GraphAbstract.h>
 #include <tulip/BooleanProperty.h>
@@ -204,7 +203,8 @@ struct TLPGraphBuilder:public TLPTrue {
   PropertyInterface* createProperty(int clusterId,
                                     const std::string& propertyType,
                                     const std::string& propertyName,
-                                    bool& isGraphProperty) {
+                                    bool& isGraphProperty,
+                                    bool& isPathViewProperty) {
     Graph* g = clusterId ? getSubGraph(clusterId) : _graph;
 
     if (g == NULL)
@@ -235,8 +235,11 @@ struct TLPGraphBuilder:public TLPTrue {
     if (propertyType==BOOL)
       return g->getLocalProperty<BooleanProperty>(propertyName);
 
-    if (propertyType==STRING)
+    if (propertyType==STRING) {
+      isPathViewProperty =
+        ((propertyName == "viewFont") || (propertyName == "viewTexture"));
       return g->getLocalProperty<StringProperty>(propertyName);
+    }
 
     if (propertyType==SIZE_VECTOR)
       return g->getLocalProperty<SizeVectorProperty>(propertyName);
@@ -262,17 +265,14 @@ struct TLPGraphBuilder:public TLPTrue {
     return NULL;
   }
   bool setNodeValue(int nodeId, PropertyInterface* prop, std::string& value,
-                    bool isGraphProperty) {
+                    bool isGraphProperty, bool isPathViewProperty) {
     node n(nodeId);
 
     if (version < 2.1)
       n = nodeIndex[nodeId];
 
     if (prop->getGraph()->isElement(n)) {
-      const std::string& propertyName = prop->getName();
-
-      if (propertyName == std::string("viewFont") ||
-          propertyName == std::string("viewTexture")) {
+      if (isPathViewProperty) {
         // if needed replace symbolic path by real path
         size_t pos = value.find("TulipBitmapDir/");
 
@@ -303,7 +303,7 @@ struct TLPGraphBuilder:public TLPTrue {
   }
 
   bool setEdgeValue(int edgeId, PropertyInterface* prop, std::string& value,
-                    bool isGraphProperty) {
+                    bool isGraphProperty, bool isPathViewProperty) {
     edge e(edgeId);
 
     if (version < 2.1)
@@ -312,8 +312,7 @@ struct TLPGraphBuilder:public TLPTrue {
     if (prop->getGraph()->isElement(e)) {
       const std::string& propertyName = prop->getName();
 
-      if (propertyName == std::string("viewFont") ||
-          propertyName == std::string("viewTexture")) {
+      if (isPathViewProperty) {
         // if needed replace symbolic path by real path
         size_t pos = value.find("TulipBitmapDir/");
 
@@ -394,7 +393,7 @@ struct TLPGraphBuilder:public TLPTrue {
   }
 
   bool setAllNodeValue(PropertyInterface* prop, std::string& value,
-                       bool isGraphProperty) {
+                       bool isGraphProperty, bool isPathViewProperty) {
     if (isGraphProperty) {
       GraphProperty* gProp = static_cast<GraphProperty*>(prop);
       char *endPtr=NULL;
@@ -410,10 +409,7 @@ struct TLPGraphBuilder:public TLPTrue {
       return true;
     }
 
-    const std::string& propertyName = prop->getName();
-
-    if (propertyName == std::string("viewFont") ||
-        propertyName == std::string("viewTexture")) {
+    if (isPathViewProperty) {
       // if needed replace symbolic path by real path
       size_t pos = value.find("TulipBitmapDir/");
 
@@ -423,8 +419,9 @@ struct TLPGraphBuilder:public TLPTrue {
 
     return prop->setAllNodeStringValue( value );
   }
+
   bool setAllEdgeValue(PropertyInterface* prop, std::string& value,
-                       bool isGraphProperty) {
+                       bool isGraphProperty, bool isPathViewProperty) {
     if (isGraphProperty) {
       GraphProperty* gProp = dynamic_cast<GraphProperty*>(prop);
       std::set<edge> v;
@@ -447,8 +444,7 @@ struct TLPGraphBuilder:public TLPTrue {
       }
     }
     else {
-      if (propertyName == std::string("viewFont") ||
-          propertyName == std::string("viewTexture")) {
+      if (isPathViewProperty) {
         // if needed replace symbolic path by real path
         size_t pos = value.find("TulipBitmapDir/");
 
@@ -654,60 +650,6 @@ struct TLPDataSetBuilder: public TLPFalse {
   virtual ~TLPDataSetBuilder() {
   }
   bool close() {
-    if (dataSetName) {
-      // handle old displaying properties
-      // to ensure compatibility
-      bool b = false;
-
-      if (dataSet.get<bool>("_viewArrow", b))
-        dataSet.set("arrow", b);
-
-      if (dataSet.get<bool>("_viewLabel", b)) {
-        dataSet.set("nodeLabel", b);
-        dataSet.set("edgeLabel", b);
-      }
-
-      if (dataSet.get<bool>("_viewNodeLabel", b))
-        dataSet.set("nodeLabel", b);
-
-      if (dataSet.get<bool>("_viewEdgeLabel", b))
-        dataSet.set("edgeLabel", b);
-
-      if (dataSet.get<bool>("_viewMetaLabel", b))
-        dataSet.set("metaLabel", b);
-
-      if (dataSet.get<bool>("_viewElementOrdered", b))
-        dataSet.set("elementOrdered", b);
-
-      if (dataSet.get<bool>("_viewStrahler", b))
-        dataSet.set("elementOrdered", b);
-
-      if (dataSet.get<bool>("_viewAutoScale", b))
-        dataSet.set("autoScale", b);
-
-      if (dataSet.get<bool>("_incrementalRendering", b))
-        dataSet.set("incrementalRendering", b);
-
-      if (dataSet.get<bool>("_edgeColorInterpolate", b))
-        dataSet.set("edgeColorInterpolation", b);
-
-      if (dataSet.get<bool>("_edgeSizeInterpolate", b))
-        dataSet.set("edgeSizeInterpolation", b);
-
-      if (dataSet.get<bool>("_edge3D", b))
-        dataSet.set("edge3D", b);
-
-      unsigned int ui = 0;
-
-      if (dataSet.get<unsigned int>("_viewOrtho", ui))
-        dataSet.set("orthogonalProjection", ui ? true : false);
-
-      if (dataSet.get<unsigned int>("_FontsType", ui))
-        dataSet.set("fontType", ui);
-
-      graphBuilder->dataSet->set(dataSetName, dataSet);
-    }
-
     return true;
   }
   bool canRead() {
@@ -722,7 +664,7 @@ struct TLPFileInfoBuilder: public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   std::string name;
 
-  TLPFileInfoBuilder(TLPGraphBuilder *graphBuilder, std::string infoName):
+  TLPFileInfoBuilder(TLPGraphBuilder *graphBuilder, const std::string& infoName):
     graphBuilder(graphBuilder), name(infoName) {
   }
   virtual ~TLPFileInfoBuilder() {
@@ -785,12 +727,15 @@ struct TLPPropertyBuilder:public TLPFalse {
   std::string propertyType,propertyName;
   PropertyInterface* property;
   bool isGraphProperty;
+  bool isPathViewProperty;
+
   virtual ~TLPPropertyBuilder() {}
-  TLPPropertyBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder), clusterId(INT_MAX), propertyType(std::string()), propertyName(std::string()), property(NULL), isGraphProperty(false) {}
+  TLPPropertyBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder), clusterId(INT_MAX), propertyType(std::string()), propertyName(std::string()), property(NULL), isGraphProperty(false), isPathViewProperty(false) {}
   void getProperty() {
     assert(property == NULL);
     property = graphBuilder->createProperty(clusterId, propertyType,
-                                            propertyName, isGraphProperty);
+                                            propertyName, isGraphProperty,
+                                            isPathViewProperty);
   }
   bool addInt(const int id)  {
     assert(id != INT_MAX);
@@ -819,25 +764,25 @@ struct TLPPropertyBuilder:public TLPFalse {
   bool setNodeValue(int nodeId, const std::string& value)  {
     return property ?
            graphBuilder->setNodeValue(nodeId, property, (std::string&) value,
-                                      isGraphProperty) :
+                                      isGraphProperty, isPathViewProperty) :
            false;
   }
   bool setEdgeValue(int edgeId, const std::string& value)  {
     return property ?
            graphBuilder->setEdgeValue(edgeId, property, (std::string&) value,
-                                      isGraphProperty) :
+                                      isGraphProperty, isPathViewProperty) :
            false;
   }
   bool setAllNodeValue(const std::string& value)  {
     return property ?
            graphBuilder->setAllNodeValue(property, (std::string&) value,
-                                         isGraphProperty) :
+                                         isGraphProperty, isPathViewProperty) :
            false;
   }
   bool setAllEdgeValue(const std::string& value)  {
     return property ?
            graphBuilder->setAllEdgeValue(property, (std::string&) value,
-                                         isGraphProperty) :
+                                         isGraphProperty, isPathViewProperty) :
            false;
   }
   bool addStruct(const std::string& structName,TLPBuilder*&newBuilder);
@@ -971,6 +916,20 @@ bool TLPGraphBuilder::addStruct(const std::string& structName,TLPBuilder*&newBui
 }
 //================================================================================
 
+// Function to retrieve the original size of a file compressed with gzip.
+// The uncompressed file size (modulo 2^32) is stored in the last four bytes of a Gzip file.
+// So that method is unreliable if the original file size was greater than 4GB (which is pretty rare for TLP files ...).
+static int getUncompressedSizeOfGzipFile(const std::string &gzipFilePath) {
+  std::istream *is = tlp::getInputFileStream(gzipFilePath.c_str(), std::ifstream::binary);
+  is->seekg (-4, is->end);
+  int uncompressedSize = 0;
+  is->read(reinterpret_cast<char*>(&uncompressedSize), 4);
+  delete is;
+  return uncompressedSize;
+}
+
+//================================================================================
+
 namespace {
 const char * paramHelp[] = {
   // filename
@@ -1023,8 +982,8 @@ public:
 
     if(dataSet->exist("file::filename")) {
       dataSet->get<std::string>("file::filename", filename);
-      struct stat infoEntry;
-      result = (stat(filename.c_str(),&infoEntry) == 0);
+      tlp_stat_t infoEntry;
+      result = (statPath(filename, &infoEntry) == 0);
 
       if (!result) {
         std::stringstream ess;
@@ -1037,16 +996,16 @@ public:
       size=infoEntry.st_size;
 
       if (filename.rfind(".gz") == (filename.length() - 3)) {
-        input = tlp::getIgzstream(filename.c_str());
-        size *= 4;
+        size = getUncompressedSizeOfGzipFile(filename);
+        input = tlp::getIgzstream(filename);
       }
       else
-        input = new std::ifstream(filename.c_str(),
-                                  std::ifstream::in |
-                                  // consider file has binary
-                                  // to avoid pb using tellg
-                                  // on the input stream
-                                  std::ifstream::binary );
+        input = tlp::getInputFileStream(filename,
+                                        std::ifstream::in |
+                                        // consider file has binary
+                                        // to avoid pb using tellg
+                                        // on the input stream
+                                        std::ifstream::binary );
     }
     else {
       dataSet->get<std::string>("file::data", data);
