@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -23,10 +23,41 @@
 #define TREEVIEWCOMBOBOX_H
 
 #include <QComboBox>
+#include <QTreeView>
+#include <QMap>
+#include <QPair>
 
 #include <tulip/tulipconf.h>
 
-class QTreeView;
+class QTimer;
+
+class TLP_QT_SCOPE DeferredUpdateTreeView : public QTreeView {
+
+  Q_OBJECT
+
+public:
+
+  DeferredUpdateTreeView(QWidget *parent = 0);
+
+  ~DeferredUpdateTreeView();
+
+protected slots:
+
+  void dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight);
+
+  void callDataChanged();
+
+  void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
+
+  void rowsInserted(const QModelIndex & parent, int start, int end);
+
+private:
+
+  void cancelUpdates(const QModelIndex &parent);
+
+  QMap<QPair<QModelIndex, QModelIndex>, QTimer *> _updateTimers;
+
+};
 
 class TLP_QT_SCOPE TreeViewComboBox : public QComboBox {
 
