@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -50,13 +50,16 @@ struct TulipFileDescriptor {
   enum FileType {File,Directory};
 
   TulipFileDescriptor() {}
-  TulipFileDescriptor(const QString& absolutePath,FileType fileType):absolutePath(absolutePath),type(fileType) {}
+  TulipFileDescriptor(const QString& absolutePath,FileType fileType, bool existing = true):absolutePath(absolutePath),type(fileType),mustExist(existing) {}
   TulipFileDescriptor(const TulipFileDescriptor& d) {
     absolutePath = d.absolutePath;
     type = d.type;
+    mustExist = d.mustExist;
   }
   QString absolutePath;
   FileType type;
+  // indicate if the file or dir must exist
+  bool mustExist;
   QString fileFilterPattern;
 };
 
