@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -238,7 +238,7 @@ void CSVImportConfigurationWidget::line(unsigned int row,const vector<string>& l
     for(size_t column = 0 ; column < lineTokens.size() ; ++column) {
       //A new column was created set its label and it's configuration widget.
       if(propertyWidgets.size()<=column) {
-        QString columnName = genrateColumnName(column);
+        QString columnName = generateColumnName(column);
         ui->previewTableWidget->setHorizontalHeaderItem(column,new QTableWidgetItem(columnName));
         //Store the first token type
         columnHeaderType.push_back(guessDataType(lineTokens[column]));
@@ -261,7 +261,7 @@ void CSVImportConfigurationWidget::line(unsigned int row,const vector<string>& l
 void CSVImportConfigurationWidget::end(unsigned int rowNumber, unsigned int) {
   maxLineNumber = rowNumber;
 
-  bool firstLineIsHeader = false;
+  /*bool firstLineIsHeader = false;
 
   //Try to guess if the first line is used as header.
   for(unsigned int i = 0 ; i< columnHeaderType.size() ; ++i) {
@@ -269,9 +269,9 @@ void CSVImportConfigurationWidget::end(unsigned int rowNumber, unsigned int) {
     if(columnHeaderType[i] != columnType[i]) {
       firstLineIsHeader = true;
     }
-  }
+    }*/
 
-  setUseFirstLineAsPropertyName(firstLineIsHeader);
+  setUseFirstLineAsPropertyName(/*firstLineIsHeader*/ true);
 
   //Force the table to correctly update.
   useFirstLineAsHeaderUpdated();
@@ -327,12 +327,13 @@ unsigned int CSVImportConfigurationWidget::rowCount()const {
 unsigned int CSVImportConfigurationWidget::columnCount()const {
   return ui->previewTableWidget->columnCount();
 }
+
 void CSVImportConfigurationWidget::updateTableHeaders() {
   QStringList itemsLabels;
 
   for(unsigned int i=0 ; i< columnCount(); ++i) {
     //Update the column name
-    QString columnName = genrateColumnName(i);
+    QString columnName = generateColumnName(i);
     itemsLabels<<columnName;
     propertyWidgets[i]->getNameLineEdit()->setText(columnName);
     //Update the column type.
@@ -351,7 +352,8 @@ void CSVImportConfigurationWidget::updateTableHeaders() {
 
   ui->previewTableWidget->setVerticalHeaderLabels(itemsLabels);
 }
-QString CSVImportConfigurationWidget::genrateColumnName(unsigned int col)const {
+
+QString CSVImportConfigurationWidget::generateColumnName(unsigned int col)const {
   if(useFirstLineAsPropertyName()) {
     QTableWidgetItem *item = ui->previewTableWidget->item(0,col);
 
@@ -437,6 +439,7 @@ void CSVImportConfigurationWidget::addPropertyToPropertyList(const string& prope
   ui->gridLayout->addWidget(propertyConfigurationWidget,0,propertyWidgets.size());
   propertyWidgets.push_back(propertyConfigurationWidget);
 }
+
 PropertyConfigurationWidget *CSVImportConfigurationWidget::createPropertyConfigurationWidget(
   unsigned int propertyNumber, const QString& propertyName, bool isEditable,
   const string& propertyType, QWidget* parent) {
@@ -449,6 +452,7 @@ PropertyConfigurationWidget *CSVImportConfigurationWidget::createPropertyConfigu
   propertyConfigurationWidget->installEventFilter(this);
   return propertyConfigurationWidget;
 }
+
 void CSVImportConfigurationWidget::propertyNameChanged(QString newName) {
   //Update headers
   PropertyConfigurationWidget *widget = qobject_cast<PropertyConfigurationWidget*>(sender());
@@ -533,7 +537,7 @@ QValidator::State PropertyNameValidator::validate(QString & input, int&) const {
   return count<=1?QValidator::Acceptable:QValidator::Invalid;
 }
 
-string CSVImportConfigurationWidget::guessPropertyDataType(const string data,const string previousType) const {
+string CSVImportConfigurationWidget::guessPropertyDataType(const string& data,const string& previousType) const {
   //If there is no data skip the token
   if(data.empty()) {
     return previousType;
@@ -543,7 +547,7 @@ string CSVImportConfigurationWidget::guessPropertyDataType(const string data,con
   return combinePropertyDataType(previousType,dataType);
 }
 
-string CSVImportConfigurationWidget::combinePropertyDataType(const string previousType,const string newType) const {
+string CSVImportConfigurationWidget::combinePropertyDataType(const string& previousType, const string& newType) const {
   if(previousType.empty()) {
     return newType;
   }
@@ -554,13 +558,23 @@ string CSVImportConfigurationWidget::combinePropertyDataType(const string previo
     //If both types are numeric return the more generic numeric type : double
     return DoubleProperty::propertyTypename;
   }
+  else if( (previousType == IntegerProperty::propertyTypename && newType == BooleanProperty::propertyTypename) || (previousType == BooleanProperty::propertyTypename && newType == IntegerProperty::propertyTypename) ) {
+    //If both types are numeric return the more generic numeric type : integer
+    return IntegerProperty::propertyTypename;
+  }
   else {
     return StringProperty::propertyTypename;
   }
 }
 
-string CSVImportConfigurationWidget::guessDataType(const string data) const {
+string CSVImportConfigurationWidget::guessDataType(const string& data) const {
   bool b;
+
+  if(BooleanType::fromString(b,data,true)) {
+    //The type is boolean
+    return BooleanProperty::propertyTypename;
+  }
+
   //Qt framework is the best way to detect numerals in string.
   QString str = QString::fromUtf8(data.c_str());
   bool isInt=false;
@@ -578,11 +592,6 @@ string CSVImportConfigurationWidget::guessDataType(const string data) const {
   if(isDouble) {
     return DoubleProperty::propertyTypename;
   }
-
-  if(BooleanType::fromString(b,data)) {
-    //The type is boolean
-    return BooleanProperty::propertyTypename;
-  }
   else {
     //All the other case are treated as string.
     return StringProperty::propertyTypename;
