@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -34,12 +34,15 @@
 #include <tulip/GlGraphComposite.h>
 #include <tulip/SnapshotDialog.h>
 #include <tulip/Gl2DRect.h>
+#include <tulip/OpenGlConfigManager.h>
 
 
 using namespace tlp;
 
-GlMainView::GlMainView(): _glMainWidget(NULL), _overviewItem(NULL), isOverviewVisible(true), _quickAccessBarItem(NULL), _quickAccessBar(NULL), _sceneConfigurationWidget(NULL), _sceneLayersConfigurationWidget(NULL), _overviewPosition(OVERVIEW_BOTTOM_RIGHT) {
-}
+GlMainView::GlMainView():
+  _glMainWidget(NULL), _overviewItem(NULL), isOverviewVisible(true),
+  _quickAccessBarItem(NULL), _quickAccessBar(NULL), _sceneConfigurationWidget(NULL),
+  _sceneLayersConfigurationWidget(NULL), _overviewPosition(OVERVIEW_BOTTOM_RIGHT), _updateOverview(true) {}
 
 GlMainView::~GlMainView() {
   delete _sceneConfigurationWidget;
@@ -64,6 +67,18 @@ void GlMainView::setOverviewPosition(const OverviewPosition &position) {
   drawOverview();
 }
 
+GlMainView::OverviewPosition GlMainView::overviewPosition() const {
+  return _overviewPosition;
+}
+
+void GlMainView::setUpdateOverview(bool updateOverview) {
+  _updateOverview = updateOverview;
+}
+
+bool GlMainView::updateOverview() const {
+  return _updateOverview;
+}
+
 void GlMainView::drawOverview(bool generatePixmap) {
   if(_overviewItem == NULL) {
     _overviewItem=new GlOverviewGraphicsItem(this,*_glMainWidget->getScene());
@@ -73,7 +88,9 @@ void GlMainView::drawOverview(bool generatePixmap) {
     sceneRectChanged(QRectF(QPoint(0, 0), graphicsView()->size()));
   }
 
-  _overviewItem->draw(generatePixmap);
+  if (_updateOverview) {
+    _overviewItem->draw(generatePixmap);
+  }
 }
 
 void GlMainView::assignNewGlMainWidget(GlMainWidget *glMainWidget, bool deleteOldGlMainWidget) {
@@ -114,8 +131,14 @@ void GlMainView::setupWidget() {
   _centerViewAction->setShortcut(tr("Ctrl+Shift+C"));
   _centerViewAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 
+  _advAntiAliasingAction = new QAction(trUtf8("Advanced anti-aliasing"), this);
+  _advAntiAliasingAction->setCheckable(true);
+  _advAntiAliasingAction->setChecked(_glMainWidget->advancedAntiAliasingActivated());
+  connect(_advAntiAliasingAction,SIGNAL(triggered(bool)),this,SLOT(setAdvancedAntiAliasing(bool)));
+
   graphicsView()->addAction(_centerViewAction);
   graphicsView()->addAction(_forceRedrawAction);
+  graphicsView()->addAction(_advAntiAliasingAction);
 }
 
 GlMainWidget* GlMainView::getGlMainWidget() const {
@@ -262,6 +285,13 @@ void GlMainView::fillContextMenu(QMenu *menu, const QPointF &) {
   viewOrtho->setChecked(_glMainWidget->getScene()->isViewOrtho());
   connect(viewOrtho,SIGNAL(triggered(bool)),this,SLOT(setViewOrtho(bool)));
 
+  QAction* antiAliasing = menu->addAction(trUtf8("Anti-aliasing"));
+  antiAliasing->setCheckable(true);
+  antiAliasing->setChecked(OpenGlConfigManager::getInst().antiAliasing());
+  connect(antiAliasing,SIGNAL(triggered(bool)),this,SLOT(setAntiAliasing(bool)));
+
+  menu->addAction(_advAntiAliasingAction);
+
   menu->addAction(trUtf8("Take snapshot"),this,SLOT(openSnapshotDialog()));
 
   menu->addSeparator();
@@ -281,6 +311,23 @@ void GlMainView::applySettings() {
   _sceneConfigurationWidget->applySettings();
 }
 
+void GlMainView::setAntiAliasing(bool aa) {
+  OpenGlConfigManager::getInst().setAntiAliasing(aa);
+  _advAntiAliasingAction->setEnabled(aa);
+
+  if (_advAntiAliasingAction->isChecked()) {
+    _advAntiAliasingAction->setChecked(false);
+  }
+  else {
+    draw();
+  }
+}
+
+void GlMainView::setAdvancedAntiAliasing(bool aaa) {
+  _glMainWidget->setAdvancedAntiAliasing(aaa);
+  draw();
+}
+
 bool GlMainView::eventFilter(QObject* obj, QEvent* event) {
   if (event->type() == QEvent::Resize) {
     // ensure automatic resize of the viewport
@@ -289,7 +336,7 @@ bool GlMainView::eventFilter(QObject* obj, QEvent* event) {
     // same for the configuration widgets
     QList<QWidget *> list = configurationWidgets();
 
-    if(!list.isEmpty()) {   //test if the current view has a configuration widget
+    if(!list.isEmpty() && list.first()->parentWidget()) {   //test if the current view has a configuration widget
       QWidget *pqw = list.first()->parentWidget()->parentWidget();
       QSize sSize = pqw->size();
       sSize.setHeight(resizeEvent->size().height() - 50);
