@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,9 @@
 #include <QGLPixelBuffer>
 #include <QGLFramebufferObject>
 #include <QGLFormat>
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+#include <QWindow>
+#endif
 #include <tulip/TulipSettings.h>
 #include <tulip/Graph.h>
 #include <tulip/GlTools.h>
@@ -70,6 +72,7 @@ static QGLFormat GlInit() {
   tmpFormat.setOverlay(false);
   tmpFormat.setStereo(false);
   tmpFormat.setSampleBuffers(true);
+  tmpFormat.setSamples(8);
   return tmpFormat;
 }
 
@@ -128,7 +131,9 @@ void GlMainWidget::doSelect(const int x, const int y,
 
 //==================================================
 GlMainWidget::GlMainWidget(QWidget *parent,View *view):
-  QGLWidget(GlInit(), parent, getFirstQGLWidget()),scene(new GlQuadTreeLODCalculator),view(view),widthStored(0),heightStored(0), useFramebufferObject(false), glFrameBuf(NULL), keepPointOfViewOnSubgraphChanging(false) {
+  QGLWidget(GlInit(), parent, getFirstQGLWidget()),scene(new GlQuadTreeLODCalculator),view(view),
+  widthStored(0),heightStored(0), useFramebufferObject(false), glFrameBuf(NULL), glFrameBuf2(NULL),
+  keepPointOfViewOnSubgraphChanging(false), advancedAntiAliasing(false) {
   assert(this->isValid());
   setFocusPolicy(Qt::StrongFocus);
   setMouseTracking(true);
@@ -137,16 +142,6 @@ GlMainWidget::GlMainWidget(QWidget *parent,View *view):
   grabGesture(Qt::SwipeGesture);
   renderingStore=NULL;
   getScene()->setViewOrtho(TulipSettings::instance().isViewOrtho());
-#if defined(__APPLE__) && defined(QT_MAC_USE_COCOA)
-  // This code is here to bug fix black screen problem on MACOSX with Qt 4.7
-  // When we do the first redraw we don't use frame backup but we draw the view
-  // We have to test with next version of Qt to check if the problem exist
-  // (It seems to no exist when Qt is built with Carbon)
-  renderingNumber=0;
-#if (QT_VERSION > QT_VERSION_CHECK(4, 7, 1))
-#warning Qt fix must be tested with this version of Qt, see GlMainWidget.cpp l.106
-#endif
-#endif
   OpenGlConfigManager::getInst().initExtensions();
 }
 //==================================================
@@ -183,18 +178,42 @@ void GlMainWidget::setupOpenGlContext() {
 //==================================================
 void GlMainWidget::createRenderingStore(int width, int height) {
 
+  useFramebufferObject = advancedAntiAliasing && QGLFramebufferObject::hasOpenGLFramebufferBlit();
+
   if (useFramebufferObject && (!glFrameBuf || glFrameBuf->size().width()!=width || glFrameBuf->size().height()!=height)) {
     makeCurrent();
-    delete glFrameBuf;
-    glFrameBuf=new QGLFramebufferObject(width,height);
+    deleteRenderingStore();
+    QGLFramebufferObjectFormat fboFormat;
+    fboFormat.setAttachment(QGLFramebufferObject::CombinedDepthStencil);
+    fboFormat.setSamples(8);
+    glFrameBuf=new QGLFramebufferObject(width,height, fboFormat);
+    glFrameBuf2=new QGLFramebufferObject(width,height);
     useFramebufferObject=glFrameBuf->isValid();
+    widthStored=width;
+    heightStored=height;
   }
 
-  if (!useFramebufferObject && (!renderingStore || width != widthStored || height != heightStored)) {
-    delete [] renderingStore;
-    renderingStore=new char[width*height*4];
+  if (!useFramebufferObject) {
+    int size = width*height;
+
+    if (renderingStore==NULL || (size > (widthStored*heightStored))) {
+      deleteRenderingStore();
+      renderingStore=new unsigned char[width*height*4];
+      widthStored=width;
+      heightStored=height;
+    }
   }
 }
+//==================================================
+void GlMainWidget::deleteRenderingStore() {
+  delete glFrameBuf;
+  glFrameBuf=NULL;
+  delete glFrameBuf2;
+  glFrameBuf2=NULL;
+  delete[] renderingStore;
+  renderingStore=NULL;
+}
+
 //==================================================
 void GlMainWidget::render(RenderingOptions options,bool checkVisibility) {
   if ((isVisible() || !checkVisibility) && !inRendering) {
@@ -208,6 +227,11 @@ void GlMainWidget::render(RenderingOptions options,bool checkVisibility) {
     int width = contentsRect().width();
     int height = contentsRect().height();
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    width *= this->windowHandle()->devicePixelRatio();
+    height *= this->windowHandle()->devicePixelRatio();
+#endif
+
     //If the rendering store is not valid need to regenerate new one force the RenderGraph flag.
     if(widthStored!=width || heightStored!=height) {
       options |= RenderScene;
@@ -218,11 +242,17 @@ void GlMainWidget::render(RenderingOptions options,bool checkVisibility) {
     if(options.testFlag(RenderScene)) {
       createRenderingStore(width,height);
 
-      widthStored=width;
-      heightStored=height;
+      if (useFramebufferObject) {
+        glFrameBuf->bind();
+      }
 
-      //Render the graph in the back buffer.
+      //Render the graph in the frame buffer.
       scene.draw();
+
+      if (useFramebufferObject) {
+        glFrameBuf->release();
+        QGLFramebufferObject::blitFramebuffer(glFrameBuf2, QRect(0,0,width, height), glFrameBuf, QRect(0,0,width, height));
+      }
     }
     else {
       scene.initGlParameters();
@@ -234,18 +264,22 @@ void GlMainWidget::render(RenderingOptions options,bool checkVisibility) {
     glDisable(GL_BLEND);
     glDisable(GL_LIGHTING);
 
-
-    if(options.testFlag(RenderScene)) {
-      //Copy the back buffer (containing the graph render) in the rendering store to reuse it later.
-      glReadBuffer(GL_BACK);
-      glReadPixels(0,0,width,height,GL_RGBA,GL_UNSIGNED_BYTE,renderingStore);
-      glFlush();
+    if (useFramebufferObject) {
+      QGLFramebufferObject::blitFramebuffer(0, QRect(0,0,width, height), glFrameBuf2, QRect(0,0,width, height));
     }
     else {
-      //Copy the rendering store into the back buffer : restore the last graph render.
-      glDrawBuffer(GL_BACK);
-      setRasterPosition(0,0);
-      glDrawPixels(width,height,GL_RGBA,GL_UNSIGNED_BYTE,renderingStore);
+      if(options.testFlag(RenderScene)) {
+        //Copy the back buffer (containing the graph render) in the rendering store to reuse it later.
+        glReadBuffer(GL_BACK);
+        glReadPixels(0,0,width,height,GL_RGBA,GL_UNSIGNED_BYTE,renderingStore);
+        glFlush();
+      }
+      else {
+        //Copy the rendering store into the back buffer : restore the last graph render.
+        glDrawBuffer(GL_BACK);
+        setRasterPosition(0,0);
+        glDrawPixels(width,height,GL_RGBA,GL_UNSIGNED_BYTE,renderingStore);
+      }
     }
 
     glEnable(GL_DEPTH_TEST);
@@ -267,36 +301,12 @@ void GlMainWidget::render(RenderingOptions options,bool checkVisibility) {
 }
 //==================================================
 void GlMainWidget::redraw() {
-
-#ifdef __APPLE__
-
-  if (isVisible() && !inRendering) {
-    // This code is here to bug fix black screen problem on MACOSX with Qt 4.7
-    // When we do the first redraw we don't use frame backup but we draw the view
-    // We have to test with next version of Qt to check if the problem exist
-    if(renderingNumber<=4) {
-      return draw(false);
-    }
-  }
-
-#endif
   render(SwapBuffers);
   emit viewRedrawn(this);
 }
 //==================================================
 void GlMainWidget::draw(bool graphChanged) {
   render(RenderingOptions(RenderScene|SwapBuffers));
-#ifdef __APPLE__
-
-  // This code is here to bug fix black screen problem on MACOSX with Qt 4.7
-  // When we do the first redraw we don't use frame backup but we draw the view
-  // We have to test with next version of Qt to check if the problem exist
-  if (isVisible() && !inRendering) {
-    if(renderingNumber<=4)
-      renderingNumber++;
-  }
-
-#endif
   emit viewDrawn(this,graphChanged);
 }
 //==================================================
@@ -341,13 +351,12 @@ void GlMainWidget::resizeGL(int w, int h) {
 
   int width = contentsRect().width();
   int height = contentsRect().height();
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+  width *= this->windowHandle()->devicePixelRatio();
+  height *= this->windowHandle()->devicePixelRatio();
+#endif
 
-  if(glFrameBuf) {
-    delete glFrameBuf;
-    glFrameBuf=NULL;
-    delete[] renderingStore;
-    renderingStore=NULL;
-  }
+  deleteRenderingStore();
 
   scene.setViewport(0,0,width,height);
 
@@ -517,11 +526,33 @@ QImage GlMainWidget::createPicture(int width, int height,bool center) {
   glFrameBuf->makeCurrent();
 
   computeInteractors();
+
+  QGLFramebufferObject *frameBuf=NULL;
+  QGLFramebufferObject *frameBuf2=NULL;
+
+  if (useFramebufferObject) {
+    QGLFramebufferObjectFormat fboFormat;
+    fboFormat.setAttachment(QGLFramebufferObject::CombinedDepthStencil);
+    fboFormat.setSamples(8);
+    frameBuf=new QGLFramebufferObject(width,height, fboFormat);
+    frameBuf2=new QGLFramebufferObject(width,height);
+    frameBuf->bind();
+  }
+
   scene.draw();
   drawInteractors();
 
+  if (useFramebufferObject) {
+    frameBuf->release();
+    QGLFramebufferObject::blitFramebuffer(frameBuf2, QRect(0,0,width, height), frameBuf, QRect(0,0,width, height));
+    QGLFramebufferObject::blitFramebuffer(0, QRect(0,0,width, height), frameBuf2, QRect(0,0,width, height));
+  }
+
   resultImage=glFrameBuf->toImage();
 
+  delete frameBuf;
+  delete frameBuf2;
+
   scene.setViewport(0,0,oldWidth,oldHeight);
 
   if(center) {
