@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -36,6 +36,7 @@
 #include <tulip/DrawingTools.h>
 #include <tulip/EdgeExtremityGlyphManager.h>
 #include <tulip/GraphNeedsSavingObserver.h>
+#include <tulip/TlpQtTools.h>
 
 #include <fstream>
 
@@ -413,19 +414,21 @@ QMimeData* GraphHierarchiesModel::mimeData(const QModelIndexList &indexes) const
 }
 
 // Graphs collection
-
 QString GraphHierarchiesModel::generateName(tlp::Graph *graph) const {
   std::string name = graph->getName();
 
-  if (name == "") {
-    name = (trUtf8("graph_") + QString::number(graph->getId())).toStdString();
+  if (name.empty()) {
+    stringstream ss;
+    ss << "graph_" << graph->getId();
+    name = ss.str();
     graph->setName(name);
   }
 
-  return QString::fromUtf8(name.c_str());
+  return tlp::tlpStringToQString(name);
 }
 
 void GraphHierarchiesModel::setCurrentGraph(tlp::Graph *g) {
+
   bool inHierarchy = false;
   foreach(Graph *i,_graphs) {
     if (i->isDescendantGraph(g) || g == i) {
@@ -440,8 +443,8 @@ void GraphHierarchiesModel::setCurrentGraph(tlp::Graph *g) {
   Graph* oldGraph = _currentGraph;
   _currentGraph = g;
 
-  if (oldGraph != NULL) {
-    QModelIndex oldRow1 = indexOf(_currentGraph);
+  if (oldGraph != NULL && oldGraph != _currentGraph) {
+    QModelIndex oldRow1 = indexOf(oldGraph);
     QModelIndex oldRow2 = createIndex(oldRow1.row(),columnCount()-1);
     emit dataChanged(oldRow1,oldRow2);
   }
@@ -468,18 +471,28 @@ void GraphHierarchiesModel::initIndexCache(tlp::Graph *root) {
   }
 }
 
+static void addListenerToWholeGraphHierarchy(Graph *root, Observable *listener) {
+  Graph *sg = NULL;
+  forEach(sg, root->getSubGraphs()) {
+    addListenerToWholeGraphHierarchy(sg, listener);
+  }
+  root->addListener(listener);
+}
+
 void GraphHierarchiesModel::addGraph(tlp::Graph *g) {
   if (_graphs.contains(g) || g == NULL)
     return;
 
-  _saveNeeded[g] = new GraphNeedsSavingObserver(g);
-
-  beginInsertRows(QModelIndex(),rowCount(),rowCount());
   Graph *i;
   foreach(i,_graphs) {
     if (i->isDescendantGraph(g))
       return;
   }
+
+  beginInsertRows(QModelIndex(),rowCount(),rowCount());
+
+  _saveNeeded[g] = new GraphNeedsSavingObserver(g);
+
   _graphs.push_back(g);
   g->getProperty<ColorProperty>("viewColor")->setMetaValueCalculator(&vColorCalc);
   g->getProperty<StringProperty>("viewLabel")->setMetaValueCalculator(&vLabelCalc);
@@ -487,7 +500,9 @@ void GraphHierarchiesModel::addGraph(tlp::Graph *g) {
   g->getProperty<SizeProperty>("viewSize")->setMetaValueCalculator(&vSizeCalc);
   g->getProperty<DoubleProperty>("viewBorderWidth")->setMetaValueCalculator(&vWidthCalc);
 
-  g->addListener(this);
+  // listen events on the whole hierarchy
+  // in order to keep track of subgraphs names, number of nodes and edges
+  addListenerToWholeGraphHierarchy(g, this);
 
   if (_graphs.size() == 1)
     setCurrentGraph(g);
@@ -524,6 +539,7 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
   if (e.type() == Event::TLP_DELETE && _graphs.contains(g)) { // A root graph has been deleted
     int pos = _graphs.indexOf(g);
     beginRemoveRows(QModelIndex(),pos,pos);
+
     _graphs.removeAll(g);
     GraphNeedsSavingObserver *s= _saveNeeded.take(g);
     delete s;
@@ -549,9 +565,17 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
       static bool removeOnAdd = false;
 
       if (ge->getType() == GraphEvent::TLP_BEFORE_ADD_DESCENDANTGRAPH) {
+        // that event must only be treated on a root graph
+        if (ge->getGraph() != ge->getGraph()->getRoot()) {
+          return;
+        }
+
         const Graph* sg = ge->getSubGraph();
+
         Graph* parentGraph = sg->getSuperGraph();
+
         QModelIndex parentIndex = indexOf(parentGraph);
+
         assert(parentIndex.isValid());
 
         if (hasIndex(parentIndex.row(), parentIndex.column(), parentIndex.parent())) {
@@ -571,16 +595,26 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
         }
       }
       else if (ge->getType() == GraphEvent::TLP_AFTER_ADD_DESCENDANTGRAPH) {
+        // that event must only be treated on a root graph
+        if (ge->getGraph() != ge->getGraph()->getRoot()) {
+          return;
+        }
+
         const Graph* sg = ge->getSubGraph();
+
         Graph* parentGraph = sg->getSuperGraph();
+
         QModelIndex parentIndex = indexOf(parentGraph);
 
         // update index cache for subgraphs of parent graph and added sub-graphs
         Graph* sg2 = NULL;
+
         int i = 0;
+
         forEach(sg2, parentGraph->getSubGraphs()) {
           _indexCache[sg2] = createIndex(i++, 0, sg2);
         }
+
         i = 0;
         forEach(sg2, sg->getSubGraphs()) {
           _indexCache[sg2] = createIndex(i++, 0, sg2);
@@ -598,15 +632,28 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
         }
 
         removeOnAdd = false;
+
+        sg->addListener(this);
+
         emit layoutChanged();
 
       }
       else if (ge->getType() == GraphEvent::TLP_BEFORE_DEL_DESCENDANTGRAPH) {
+        // that event must only be treated on a root graph
+        if (ge->getGraph() != ge->getGraph()->getRoot()) {
+          return;
+        }
+
         const Graph* sg = ge->getSubGraph();
+
         Graph* parentGraph = sg->getSuperGraph();
+
         QModelIndex index = indexOf(sg);
+
         assert(index.isValid());
+
         QModelIndex parentIndex = indexOf(parentGraph);
+
         assert(parentIndex.isValid());
 
         int nbRowsToAdd = sg->numberOfSubGraphs() - 1;
@@ -622,20 +669,33 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
 
       }
       else if (ge->getType() == GraphEvent::TLP_AFTER_DEL_DESCENDANTGRAPH) {
+        // that event must only be treated on a root graph
+        if (ge->getGraph() != ge->getGraph()->getRoot()) {
+          return;
+        }
+
         const Graph* sg = ge->getSubGraph();
+
         Graph* parentGraph = sg->getSuperGraph();
+
         QModelIndex index = indexOf(sg);
+
         assert(index.isValid());
+
 #ifndef NDEBUG
         QModelIndex parentIndex = indexOf(parentGraph);
+
         assert(parentIndex.isValid());
+
 #endif
 
         emit layoutAboutToBeChanged();
 
         // update index cache for subgraphs of parent graph
         Graph* sg2 = NULL;
+
         int i = 0;
+
         forEach(sg2, parentGraph->getSubGraphs()) {
           _indexCache[sg2] = createIndex(i++, 0, sg2);
         }
@@ -653,8 +713,38 @@ void GraphHierarchiesModel::treatEvent(const Event &e) {
           endRemoveRows();
         }
 
+        sg->removeListener(this);
+
         emit layoutChanged();
       }
+      else if (ge->getType() == GraphEvent::TLP_ADD_NODE || ge->getType() == GraphEvent::TLP_ADD_NODES ||
+               ge->getType() == GraphEvent::TLP_DEL_NODE) {
+        const Graph *graph = ge->getGraph();
+        QModelIndex graphIndex = indexOf(graph);
+        QModelIndex graphNodesIndex = graphIndex.sibling(graphIndex.row(), NODES_SECTION);
+        emit dataChanged(graphNodesIndex, graphNodesIndex);
+
+      }
+      else if (ge->getType() == GraphEvent::TLP_ADD_EDGE || ge->getType() == GraphEvent::TLP_ADD_EDGES ||
+               ge->getType() == GraphEvent::TLP_DEL_EDGE) {
+        const Graph *graph = ge->getGraph();
+        QModelIndex graphIndex = indexOf(graph);
+        QModelIndex graphEdgesIndex = graphIndex.sibling(graphIndex.row(), EDGES_SECTION);
+        emit dataChanged(graphEdgesIndex, graphEdgesIndex);
+      }
     }
   }
+  else if (e.type() == Event::TLP_INFORMATION) {
+    const GraphEvent *ge = dynamic_cast<const tlp::GraphEvent *>(&e);
+
+    if (!ge)
+      return;
+
+    if (ge->getType() == GraphEvent::TLP_AFTER_SET_ATTRIBUTE && ge->getAttributeName() == "name") {
+      const Graph *graph = ge->getGraph();
+      QModelIndex graphIndex = indexOf(graph);
+      emit dataChanged(graphIndex, graphIndex);
+    }
+
+  }
 }
