@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -495,6 +495,9 @@ void NodesGraphModel::setGraph(Graph* g) {
   node n;
   forEach(n,graph()->getNodes())
   _elements[i++] = n.id;
+  // we ensure the ids are ascendingly sorted
+  // to ease the display of nodes/edges
+  qSort(_elements);
   //reset();
 }
 
