@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -336,6 +336,8 @@ public:
   }
   ~TulipFileDialog() {}
   int ok;
+  TulipFileDescriptor previousFileDescriptor;
+
   void done(int res) {
     ok = res;
     QFileDialog::done(res);
@@ -358,22 +360,26 @@ QWidget* TulipFileDescriptorEditorCreator::createWidget(QWidget*) const {
 
 void TulipFileDescriptorEditorCreator::setEditorData(QWidget* w, const QVariant& v, bool, tlp::Graph*) {
   TulipFileDescriptor desc = v.value<TulipFileDescriptor>();
-  QFileDialog* dlg = static_cast<QFileDialog*>(w);
-  QString path;
+  TulipFileDialog* dlg = static_cast<TulipFileDialog*>(w);
+  dlg->previousFileDescriptor = desc;
 
-  if (desc.absolutePath.isEmpty())
-    path = QDir::currentPath();
-  else
-    path = QFileInfo(desc.absolutePath).absolutePath();
-
-  dlg->setDirectory(path);
+  // force the dialog initial directory
+  // only if there is a non empty absolute path
+  if (!desc.absolutePath.isEmpty())
+    dlg->setDirectory(QFileInfo(desc.absolutePath).absolutePath());
+  // or if we are in gui testing mode
+  // where we must ensure that choosing the file is relative to
+  // the current directory to allow to run the gui tests
+  // from any relative unit_test/gui directory
+  else if (inGuiTestingMode())
+    dlg->setDirectory(QDir::currentPath());
 
   if (desc.type == TulipFileDescriptor::Directory) {
     dlg->setFileMode(QFileDialog::Directory);
     dlg->setOption(QFileDialog::ShowDirsOnly);
   }
   else
-    dlg->setFileMode(QFileDialog::ExistingFile);
+    dlg->setFileMode(desc.mustExist ? QFileDialog::ExistingFile : QFileDialog::AnyFile);
 
   dlg->setModal(true);
   dlg->move(QCursor::pos() - QPoint(150, 200));
@@ -385,7 +391,7 @@ QVariant TulipFileDescriptorEditorCreator::editorData(QWidget* w,tlp::Graph*) {
   int result = dlg->ok;
 
   if (result == QDialog::Rejected)
-    return QVariant();
+    return QVariant::fromValue<TulipFileDescriptor>(dlg->previousFileDescriptor);
 
   if (dlg->fileMode() == QFileDialog::Directory) {
     return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(dlg->directory().absolutePath(),TulipFileDescriptor::Directory));
@@ -733,7 +739,7 @@ QString EdgeSetEditorCreator::displayText(const QVariant& var) const {
 }
 
 QWidget* QVectorBoolEditorCreator::createWidget(QWidget*) const {
-  VectorEditionWidget* w = new VectorEditionWidget(NULL);
+  VectorEditor* w = new VectorEditor(NULL);
   w->setWindowFlags(Qt::Dialog);
   w->setWindowModality(Qt::ApplicationModal);
   return w;
@@ -747,14 +753,14 @@ void QVectorBoolEditorCreator::setEditorData(QWidget* editor, const QVariant& v,
     editorData.push_back(QVariant::fromValue<bool>(vect[i]));
   }
 
-  static_cast<VectorEditionWidget*>(editor)->setVector(editorData,qMetaTypeId<bool>());
+  static_cast<VectorEditor*>(editor)->setVector(editorData,qMetaTypeId<bool>());
 
-  static_cast<VectorEditionWidget*>(editor)->move(QCursor::pos());
+  static_cast<VectorEditor*>(editor)->move(QCursor::pos());
 }
 
 QVariant QVectorBoolEditorCreator::editorData(QWidget* editor,tlp::Graph*) {
   QVector<bool> result;
-  QVector<QVariant> editorData = static_cast<VectorEditionWidget*>(editor)->vector();
+  QVector<QVariant> editorData = static_cast<VectorEditor*>(editor)->vector();
   foreach(QVariant v, editorData)
   result.push_back(v.value<bool>());
   return QVariant::fromValue<QVector<bool> >(result);
@@ -792,16 +798,20 @@ QString QVectorBoolEditorCreator::displayText(const QVariant &data) const {
 
 //QStringEditorCreator
 QWidget* QStringEditorCreator::createWidget(QWidget *parent) const {
-  return new QLineEdit(parent);
+  QTextEdit *edit = new QTextEdit(parent);
+  edit->setFocusPolicy(Qt::StrongFocus);
+  edit->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+  edit->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+  return edit;
 }
 
-void QStringEditorCreator::setEditorData(QWidget* w, const QVariant& var, bool, tlp::Graph*) {
-  static_cast<QLineEdit*>(w)->setText(var.toString());
-  static_cast<QLineEdit*>(w)->selectAll();
+void QStringEditorCreator::setEditorData(QWidget* editor, const QVariant& var, bool, tlp::Graph*) {
+  static_cast<QTextEdit*>(editor)->setPlainText(var.toString());
+  static_cast<QTextEdit*>(editor)->selectAll();
 }
 
-QVariant QStringEditorCreator::editorData(QWidget* w,tlp::Graph*) {
-  return static_cast<QLineEdit*>(w)->text();
+QVariant QStringEditorCreator::editorData(QWidget* editor,tlp::Graph*) {
+  return static_cast<QTextEdit*>(editor)->toPlainText();
 }
 
 QString QStringEditorCreator::displayText(const QVariant& var) const {
@@ -809,7 +819,7 @@ QString QStringEditorCreator::displayText(const QVariant& var) const {
 }
 
 QWidget *QStringListEditorCreator::createWidget(QWidget *) const {
-  VectorEditionWidget* w = new VectorEditionWidget(NULL);
+  VectorEditor* w = new VectorEditor(NULL);
   w->setWindowFlags(Qt::Dialog);
   w->setWindowModality(Qt::ApplicationModal);
   return w;
@@ -823,11 +833,11 @@ void QStringListEditorCreator::setEditorData(QWidget *w, const QVariant &var, bo
   foreach(QString s, strList) {
     vect[i++] = s;
   }
-  static_cast<VectorEditionWidget*>(w)->setVector(vect,qMetaTypeId<QString>());
+  static_cast<VectorEditor*>(w)->setVector(vect,qMetaTypeId<QString>());
 }
 
 QVariant QStringListEditorCreator::editorData(QWidget* w, Graph*) {
-  QVector<QVariant> vect = static_cast<VectorEditionWidget*>(w)->vector();
+  QVector<QVariant> vect = static_cast<VectorEditor*>(w)->vector();
   QStringList lst;
   foreach(QVariant v, vect)
   lst.push_back(v.toString());
