@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -25,6 +25,7 @@
 #include <tulip/GlyphManager.h>
 #include <tulip/TulipRelease.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/TlpTools.h>
 
 #include <QtCore/QFileInfo>
 #include <QtCore/QStringList>
@@ -53,6 +54,7 @@ const QString TulipSettings::ProxyUseAuthEntry = "app/proxy/user";
 const QString TulipSettings::ProxyUsernameEntry = "app/proxy/useAuth";
 const QString TulipSettings::ProxyPasswordEntry = "app/proxy/passwd";
 
+const QString TulipSettings::AutomaticDisplayDefaultViews = "graph/auto/defaultViews";
 const QString TulipSettings::AutomaticPerfectAspectRatioEntry = "graph/auto/ratio";
 const QString TulipSettings::ViewOrthoEntry = "graph/auto/ortho";
 const QString TulipSettings::AutomaticMapMetricEntry = "graph/auto/colors";
@@ -61,6 +63,8 @@ const QString TulipSettings::ResultPropertyStoredEntry = "graph/auto/result";
 
 const QString TulipSettings::RunningTimeComputedEntry = "graph/auto/time";
 
+const QString TulipSettings::SeedForRandomSequenceEntry = "graph/auto/seed";
+
 const QString TulipSettings::WarnUserAboutGraphicsCardEntry = "app/warn_about_graphics_card";
 
 TulipSettings::TulipSettings(): QSettings("TulipSoftware","Tulip") {
@@ -323,6 +327,14 @@ void TulipSettings::setFirstRun(bool f) {
   setValue(FirstRunEntry,f);
 }
 
+bool TulipSettings::displayDefaultViews() const {
+  return value(AutomaticDisplayDefaultViews, true).toBool();
+}
+
+void TulipSettings::setDisplayDefaultViews(bool f) {
+  setValue(AutomaticDisplayDefaultViews,f);
+}
+
 bool TulipSettings::isAutomaticMapMetric() const {
   return value(AutomaticMapMetricEntry,false).toBool();
 }
@@ -367,6 +379,19 @@ void TulipSettings::setRunningTimeComputed(bool f) {
   setValue(RunningTimeComputedEntry,f);
 }
 
+unsigned int TulipSettings::seedOfRandomSequence() const {
+  return value(SeedForRandomSequenceEntry,
+               tlp::getSeedOfRandomSequence()).toUInt();
+}
+
+void TulipSettings::setSeedOfRandomSequence(unsigned int seed) {
+  setValue(SeedForRandomSequenceEntry, seed);
+}
+
+void TulipSettings::initSeedOfRandomSequence() {
+  tlp::setSeedOfRandomSequence(seedOfRandomSequence());
+}
+
 bool TulipSettings::warnUserAboutGraphicsCard() const {
   return value(WarnUserAboutGraphicsCardEntry,true).toBool();
 }
