@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -46,7 +46,8 @@ using namespace tlp;
   Helper storage class to ensure synchronization between panels list and model passed down to opened panels
   */
 Workspace::Workspace(QWidget *parent)
-  : QWidget(parent), _ui(new Ui::Workspace), _currentPanelIndex(0), _oldWorkspaceMode(NULL), _focusedPanel(NULL), _focusedPanelHighlighting(false), _model(NULL), _pageCountLabel(NULL) {
+  : QWidget(parent), _ui(new Ui::Workspace), _currentPanelIndex(0), _oldWorkspaceMode(NULL), _focusedPanel(NULL),
+    _focusedPanelHighlighting(false), _model(NULL), _pageCountLabel(NULL), _autoCenterViews(false) {
   _ui->setupUi(this);
   _ui->startupMainFrame->hide();
   _pageCountLabel = _ui->pagesLabel;
@@ -59,6 +60,7 @@ Workspace::Workspace(QWidget *parent)
   _modeToSlots[_ui->startupPage] = QVector<PlaceHolderWidget*>();
   _modeToSlots[_ui->singlePage] = QVector<PlaceHolderWidget*>() << _ui->singlePage;
   _modeToSlots[_ui->splitPage] = QVector<PlaceHolderWidget*>() << _ui->splitPagePanel1 << _ui->splitPagePanel2;
+  _modeToSlots[_ui->splitPageHorizontal] = QVector<PlaceHolderWidget*>() << _ui->splitPageHorizontalPanel1 << _ui->splitPageHorizontalPanel2;
   _modeToSlots[_ui->split3Page] = QVector<PlaceHolderWidget*>() << _ui->split3PagePanel1 << _ui->split3PagePanel2 << _ui->split3PagePanel3;
   _modeToSlots[_ui->split32Page] = QVector<PlaceHolderWidget*>() << _ui->split32Panel1 << _ui->split32Panel2 << _ui->split32Panel3;
   _modeToSlots[_ui->split33Page] = QVector<PlaceHolderWidget*>() << _ui->split33Panel1 << _ui->split33Panel2 << _ui->split33Panel3;
@@ -68,6 +70,7 @@ Workspace::Workspace(QWidget *parent)
   // This map allows us to know which widget can toggle a mode
   _modeSwitches[_ui->singlePage] = _ui->singleModeButton;
   _modeSwitches[_ui->splitPage] = _ui->splitModeButton;
+  _modeSwitches[_ui->splitPageHorizontal] = _ui->splitHorizontalModeButton;
   _modeSwitches[_ui->split3Page] = _ui->split3ModeButton;
   _modeSwitches[_ui->split32Page] = _ui->split32ModeButton;
   _modeSwitches[_ui->split33Page] = _ui->split33ModeButton;
@@ -230,6 +233,7 @@ void Workspace::switchToSingleMode() {
 void Workspace::setSingleModeSwitch(QWidget* w) {
   _modeSwitches[_ui->singlePage] = w;
 }
+
 void Workspace::switchToSplitMode() {
   switchWorkspaceMode(_ui->splitPage);
 }
@@ -237,6 +241,15 @@ void Workspace::switchToSplitMode() {
 void Workspace::setSplitModeSwitch(QWidget *w) {
   _modeSwitches[_ui->splitPage] = w;
 }
+
+void Workspace::switchToSplitHorizontalMode() {
+  switchWorkspaceMode(_ui->splitPageHorizontal);
+}
+
+void Workspace::setSplitHorizontalModeSwitch(QWidget *w) {
+  _modeSwitches[_ui->splitPageHorizontal] = w;
+}
+
 void Workspace::switchToSplit3Mode() {
   switchWorkspaceMode(_ui->split3Page);
 }
