@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -140,7 +140,7 @@ void WorkspacePanel::setView(tlp::View* view) {
   delete _view;
 
   _view = view;
-  _viewName = view->name().c_str();
+  _viewName = tlp::tlpStringToQString(view->name());
 
   QList<Interactor*> compatibleInteractors;
   QList<std::string> interactorNames = InteractorLister::compatibleInteractors(view->name());
@@ -226,6 +226,7 @@ void WorkspacePanel::setCurrentInteractor(tlp::Interactor *i) {
   _ui->currentInteractorButton->setText(i->action()->text());
   _ui->currentInteractorButton->setIcon(i->action()->icon());
   _ui->currentInteractorButton->setChecked(false);
+  _ui->currentInteractorButton->setToolTip(QString("Active tool:<br/><b>") + i->action()->text() + QString("</b><br/><i>click to show/hide its configuration panel.</i>"));
 }
 
 void WorkspacePanel::setCurrentInteractorConfigurationVisible(bool toggle) {
@@ -328,7 +329,7 @@ void WorkspacePanel::refreshInteractorsToolbar() {
   }
 
   delete _ui->interactorsFrame->layout();
-  bool interactorsUiShown = compatibleInteractors.size() > 0;
+  bool interactorsUiShown = !compatibleInteractors.isEmpty();
   _ui->currentInteractorButton->setVisible(interactorsUiShown);
   _ui->interactorsFrame->setVisible(interactorsUiShown);
   _ui->sep1->setVisible(interactorsUiShown);
@@ -394,7 +395,7 @@ void WorkspacePanel::viewGraphSet(tlp::Graph* g) {
 #ifndef NDEBUG
 
   if(g) {
-    qDebug() << "Setting graph " << g->getName() << " for panel " << windowTitle();
+    qDebug() << "Setting graph " << tlp::tlpStringToQString(g->getName()) << " for panel " << windowTitle();
   }
 
 #endif // NDEBUG
@@ -413,7 +414,7 @@ void WorkspacePanel::graphComboIndexChanged() {
 #ifndef NDEBUG
 
   if (g != NULL) {
-    qDebug() << "selecting graph " << g->getName() << " in view";
+    qDebug() << "selecting graph " << tlp::tlpStringToQString(g->getName()) << " in view";
   }
 
 #endif /* NDEBUG */
