@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -18,8 +18,6 @@
  */
 
 #include <GL/glew.h>
-
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/AbstractGlCurve.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/Curves.h>
@@ -802,7 +800,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
     if (lineCurve) {
       glLineWidth(curveLineWidth);
-      OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
 
       if (vboOk) {
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[2]);
@@ -812,7 +809,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
         glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][1]);
       }
 
-      OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
     }
     else {
       if (texture != "") {
@@ -830,8 +826,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
         GlTextureManager::getInst().activateTexture(TulipBitmapDir+"cylinderTexture.png");
       }
 
-      OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-
       if (vboOk) {
         if (geometryShaderActivated) {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[3]);
@@ -851,8 +845,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
         }
       }
 
-      OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-
       if (billboardCurve) {
         glActiveTexture(GL_TEXTURE1);
         GlTextureManager::getInst().desactivateTexture();
@@ -913,8 +905,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
 
         glLineWidth(curveQuadBordersWidth);
 
-        OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
         if (vboOk) {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, vbo[3]);
 
@@ -957,8 +947,6 @@ void AbstractGlCurve::drawCurve(std::vector<Coord> &controlPoints, const Color &
             glDrawElements(GL_LINE_STRIP, nbCurvePoints, GL_UNSIGNED_SHORT, curveVertexBuffersIndices[nbCurvePoints][3]);
           }
         }
-
-        OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
       }
     }
 
