@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -23,7 +23,6 @@
 #include <tulip/GlTools.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/ParametricCurves.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlShaderProgram.h>
 #include <tulip/GlXMLTools.h>
 
@@ -539,8 +538,6 @@ void GlComplexPolygon::draw(float,Camera *) {
   glEnableClientState(GL_VERTEX_ARRAY);
   glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-
   setMaterial(fillColor);
 
   for (set<GLenum>::iterator it = primitivesSet.begin() ; it != primitivesSet.end() ; ++it) {
@@ -552,8 +549,6 @@ void GlComplexPolygon::draw(float,Camera *) {
     }
   }
 
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-
   glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
   if(textureName!="") {
@@ -569,14 +564,10 @@ void GlComplexPolygon::draw(float,Camera *) {
     glLineWidth(lineWidth);
     setMaterial(outlineColor);
 
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
     for(size_t v = 0 ; v < points.size() ; ++v) {
       glVertexPointer(3, GL_FLOAT, 3 * sizeof(GLfloat), &points[v][0]);
       glDrawArrays(GL_LINE_LOOP, 0, points[v].size());
     }
-
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
   }
 
 
@@ -598,8 +589,6 @@ void GlComplexPolygon::draw(float,Camera *) {
 
         if (outlineExtrusionShader->isLinked()) {
 
-          OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-
           outlineExtrusionShader->activate();
 
           GLint vertexPosLoc = glGetAttribLocation(outlineExtrusionShader->getShaderProgramId(),"indice");
@@ -631,8 +620,6 @@ void GlComplexPolygon::draw(float,Camera *) {
 
           outlineExtrusionShader->desactivate();
 
-          OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-
         }
       }
 
