@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -46,7 +46,6 @@
 #include <tulip/GlLabel.h>
 #include <tulip/ParametricCurves.h>
 #include <tulip/GlGraphInputData.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlScene.h>
 #include <tulip/GlGlyphRenderer.h>
 #include <tulip/TulipViewSettings.h>
@@ -157,16 +156,12 @@ void GlEdge::draw(float lod, const GlGraphInputData* data, Camera* camera) {
       Color srcCol, tgtCol;
       getEdgeColor(data,e,source,target,selected,srcCol,tgtCol);
 
-      OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
       setColor(srcCol);
       glPointSize(1);
       glBegin(GL_POINTS);
       glVertex3f(srcCoord[0], srcCoord[1], srcCoord[2]);
       glEnd();
 
-      OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
-
     }
 
     return;
@@ -872,9 +867,21 @@ void GlEdge::displayArrowAndAdjustAnchor(const GlGraphInputData *data,
     // edge extremity glyph is in the viewport
     if (lod > 0) {
 
+      // Some glyphs can not benefit from the shader rendering optimization
+      // due to the use of quadrics or modelview matrix modification or lighting effect
+      static set<int> noShaderGlyphs;
+
+      if (noShaderGlyphs.empty()) {
+        noShaderGlyphs.insert(EdgeExtremityShape::Cone);
+        noShaderGlyphs.insert(EdgeExtremityShape::Cylinder);
+        noShaderGlyphs.insert(EdgeExtremityShape::GlowSphere);
+        noShaderGlyphs.insert(EdgeExtremityShape::Sphere);
+        noShaderGlyphs.insert(EdgeExtremityShape::Cube);
+      }
+
       Color borderColor = data->parameters->isEdgeColorInterpolate() ? color : data->getElementBorderColor()->getEdgeValue(e);
 
-      if (data->getGlGlyphRenderer()->renderingHasStarted()) {
+      if (data->getGlGlyphRenderer()->renderingHasStarted() && noShaderGlyphs.find(extremityGlyph->id()) == noShaderGlyphs.end()) {
         data->getGlGlyphRenderer()->addEdgeExtremityGlyphRendering(extremityGlyph, e, source, color, borderColor, 100., beginTmpAnchor, srcAnchor, size, selected);
       }
       else {
