@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -19,7 +19,7 @@
 #include <tulip/GlGraphHighDetailsRenderer.h>
 #include <tulip/ForEach.h>
 #include <tulip/GraphProperty.h>
-#include <tulip/DoubleProperty.h>
+#include <tulip/NumericProperty.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlLODSceneVisitor.h>
@@ -34,6 +34,7 @@
 #include <tulip/GlGraphInputData.h>
 #include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/GlGlyphRenderer.h>
+#include <tulip/OpenGlConfigManager.h>
 
 using namespace std;
 
@@ -137,9 +138,9 @@ const GlGraphInputData *entityWithDistanceCompare::inputData=NULL;
  */
 class GreatThanNode {
 public:
-  DoubleProperty *metric;
+  NumericProperty *metric;
   bool operator() (pair<node,float> n1,pair<node,float> n2)  {
-    return (metric->getNodeValue(n1.first) > metric->getNodeValue(n2.first));
+    return (metric->getNodeDoubleValue(n1.first) > metric->getNodeDoubleValue(n2.first));
   }
 };
 /** \brief Comparator to order entities with metric to display labels with metric ordering
@@ -147,9 +148,9 @@ public:
  */
 class GreatThanEdge {
 public:
-  DoubleProperty *metric;
+  NumericProperty *metric;
   bool operator() (pair<edge,float> e1,pair<edge,float> e2) {
-    return (metric->getEdgeValue(e1.first) > metric->getEdgeValue(e2.first));
+    return (metric->getEdgeDoubleValue(e1.first) > metric->getEdgeDoubleValue(e2.first));
   }
 };
 
@@ -178,6 +179,10 @@ GlGraphHighDetailsRenderer::~GlGraphHighDetailsRenderer() {
 //===================================================================
 void GlGraphHighDetailsRenderer::draw(float,Camera* camera) {
 
+  if (!inputData->renderingParameters()->isAntialiased()) {
+    OpenGlConfigManager::getInst().desactivateAntiAliasing();
+  }
+
   Graph *graph=inputData->getGraph();
 
   // If we don't init lod calculator : clone the scene one
@@ -241,7 +246,7 @@ void GlGraphHighDetailsRenderer::draw(float,Camera* camera) {
   }
 
   BooleanProperty *filteringProperty = inputData->parameters->getDisplayFilteringProperty();
-  DoubleProperty *metric=inputData->parameters->getElementOrderingProperty();
+  NumericProperty *metric=inputData->parameters->getElementOrderingProperty();
   bool displayNodes = inputData->parameters->isDisplayNodes();
   bool displayMetaNodes = inputData->parameters->isDisplayMetaNodes();
   bool displayMetaNodesLabel = inputData->parameters->isViewMetaLabel();
@@ -253,9 +258,14 @@ void GlGraphHighDetailsRenderer::draw(float,Camera* camera) {
   bool renderOnlyOneNode=false;
 
   if(!selectionDrawActivate) {
-    if(!inputData->getElementLayout()->getNonDefaultValuatedNodes()->hasNext() &&
-        !inputData->getElementSize()->getNonDefaultValuatedNodes()->hasNext())
+    Iterator<node> *nonDefaultLayoutNodes = inputData->getElementLayout()->getNonDefaultValuatedNodes();
+    Iterator<node> *nonDefaultSizeNodes = inputData->getElementSize()->getNonDefaultValuatedNodes();
+
+    if(!nonDefaultLayoutNodes->hasNext() && !nonDefaultSizeNodes->hasNext())
       renderOnlyOneNode=true;
+
+    delete nonDefaultLayoutNodes;
+    delete nonDefaultSizeNodes;
   }
 
   if(!inputData->parameters->isElementZOrdered()) {
@@ -494,6 +504,7 @@ void GlGraphHighDetailsRenderer::draw(float,Camera* camera) {
   else {
     selectionDrawActivate=false;
     inputData->getGlVertexArrayManager()->activate(true);
+    OpenGlConfigManager::getInst().activateAntiAliasing();
     return;
   }
 
@@ -523,6 +534,9 @@ void GlGraphHighDetailsRenderer::draw(float,Camera* camera) {
   }
 
   selectionDrawActivate=false;
+
+  OpenGlConfigManager::getInst().activateAntiAliasing();
+
 }
 //===================================================================
 void GlGraphHighDetailsRenderer::selectEntities(Camera *camera,RenderingEntitiesFlag type, int x, int y, int w, int h, vector<SelectedEntity> &selectedEntities) {
@@ -569,7 +583,7 @@ void GlGraphHighDetailsRenderer::drawLabelsForComplexEntities(bool drawSelected,
   Graph *graph=inputData->getGraph();
   BooleanProperty *selectionProperty=inputData->getElementSelected();
   bool viewOutScreenLabel=inputData->parameters->isViewOutScreenLabel();
-  DoubleProperty *metric=inputData->parameters->getElementOrderingProperty();
+  NumericProperty *metric=inputData->parameters->getElementOrderingProperty();
   BooleanProperty *filteringProperty = inputData->parameters->getDisplayFilteringProperty();
 
   vector<pair<node,float> > nodesMetricOrdered;
