@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -27,7 +27,6 @@
 #include <tulip/SizeProperty.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/ColorProperty.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlyphManager.h>
 #include <tulip/GlDisplayListManager.h>
@@ -42,6 +41,30 @@ using namespace std;
 
 namespace tlp {
 
+// FTGL fonts must be cached to avoid to much memory consumption
+static TLP_HASH_MAP<std::string, FTPolygonFont*> PolygonFonts;
+static TLP_HASH_MAP<std::string, FTGLOutlineFont*> OutlineFonts;
+
+static FTPolygonFont* getPolygonFont(const std::string& name) {
+  TLP_HASH_MAP<std::string, FTPolygonFont*>::iterator itf =
+    PolygonFonts.find(name);
+
+  if (itf != PolygonFonts.end())
+    return itf->second;
+
+  return PolygonFonts[name] = new FTPolygonFont(name.c_str());
+}
+
+static FTGLOutlineFont* getOutlineFont(const std::string& name) {
+  TLP_HASH_MAP<std::string, FTGLOutlineFont*>::iterator itf =
+    OutlineFonts.find(name);
+
+  if (itf != OutlineFonts.end())
+    return itf->second;
+
+  return OutlineFonts[name] = new FTGLOutlineFont(name.c_str());
+}
+
 static const int SpaceBetweenLine=5;
 
 GlLabel::GlLabel():oldCamera(NULL) {
@@ -52,16 +75,14 @@ GlLabel::GlLabel(Coord centerPosition,Size size,Color fontColor,bool leftAlign):
 }
 
 GlLabel::~GlLabel() {
-  delete font;
-  delete borderFont;
 }
 //============================================================
 void GlLabel::init() {
   fontName=TulipBitmapDir + "font.ttf";
-  font=new FTPolygonFont(fontName.c_str());
+  font=getPolygonFont(fontName);
 
   if(font->Error()==0) { //no error
-    borderFont=new FTGLOutlineFont(fontName.c_str());
+    borderFont=getOutlineFont(fontName);
     fontSize=20;
     font->FaceSize(fontSize);
     borderFont->FaceSize(fontSize);
@@ -92,6 +113,7 @@ void GlLabel::init() {
 }
 //============================================================
 void GlLabel::setText(const string& text) {
+
   this->text=text;
 
   if (font->Error())
@@ -106,15 +128,17 @@ void GlLabel::setText(const string& text) {
   textVector.clear();
   textWidthVector.clear();
   size_t lastPos=0;
-  size_t pos=text.find_first_of("\n");
+  size_t pos=this->text.find_first_of("\n");
 
   while(pos!=string::npos) {
-    textVector.push_back(text.substr(lastPos,pos-lastPos));
+    string s = this->text.substr(lastPos,pos-lastPos);
+    textVector.push_back(s);
     lastPos=pos+1;
-    pos=text.find_first_of("\n",pos+1);
+    pos=this->text.find_first_of("\n",pos+1);
   }
 
-  textVector.push_back(text.substr(lastPos)+" ");
+  string s = this->text.substr(lastPos)+" ";
+  textVector.push_back(s);
 
   //Text bounding box computation
   textBoundingBox=BoundingBox();
@@ -206,10 +230,8 @@ void GlLabel::setFontName(const std::string &name) {
 
   fontName=name;
 
-  delete font;
-  delete borderFont;
-  font=new FTGLPolygonFont(fontName.c_str());
-  borderFont=new FTOutlineFont(fontName.c_str());
+  font=getPolygonFont(fontName);
+  borderFont=getOutlineFont(fontName);
 
   if(font->Error() || borderFont->Error()) {
     if(fontName=="")
@@ -217,11 +239,8 @@ void GlLabel::setFontName(const std::string &name) {
     else
       tlp::warning() << "Error in font loading: " << fontName << " cannot be loaded" << endl;
 
-    delete font;
-    delete borderFont;
-
-    font=new FTPolygonFont((TulipBitmapDir + "font.ttf").c_str());
-    borderFont=new FTGLOutlineFont((TulipBitmapDir + "font.ttf").c_str());
+    font=getPolygonFont((TulipBitmapDir + "font.ttf"));
+    borderFont=getOutlineFont((TulipBitmapDir + "font.ttf"));
   }
 }
 //============================================================
@@ -598,12 +617,10 @@ void GlLabel::draw(float, Camera *camera) {
     else
       setMaterial(Color(outlineColor[0],outlineColor[1],outlineColor[2],outlineColor[3]));
 
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
     glBegin(GL_LINES);
     glVertex3f(-w/2.+wAlign,hAlign,0);
     glVertex3f(w/2.+wAlign,hAlign,0);
     glEnd();
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
     glLineWidth(1);
   }
   else {
@@ -671,9 +688,7 @@ void GlLabel::draw(float, Camera *camera) {
       setMaterial(color);
 
       if (screenH > 6 || outlineColor.getA()==0 || outlineSize==0) {
-        OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
         font->Render((*it).c_str(),-1,shift);
-        OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
       }
 
       if(textureName!="")
@@ -689,9 +704,7 @@ void GlLabel::draw(float, Camera *camera) {
 
         setMaterial(outlineColor);
 
-        OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
         borderFont->Render((*it).c_str(),-1,shift);
-        OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
       }
 
       yShift-=fontSize+5;
