@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -19,11 +19,17 @@
 
 #include <cstdio>
 #include <cstring>
+#if defined(_MSC_VER)
+// need to include that header with Visual Studio to fix a typedef conflict
+// with latest version of jpeg lib (9a)
+#include <basetsd.h>
+#endif
 #include <jpeglib.h>
 #include <png.h>
 #include <GL/glew.h>
 
 #include <tulip/GlTextureManager.h>
+#include <tulip/OpenGlConfigManager.h>
 
 //====================================================
 tlp::GlTextureManager* tlp::GlTextureManager::inst=NULL;
@@ -319,7 +325,7 @@ static bool generateTexture(const std::string &filename,
       }
     }
 
-    static bool canUseNpotTextures = glewIsSupported("GL_ARB_texture_non_power_of_two") == GL_TRUE;
+    bool canUseNpotTextures = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_texture_non_power_of_two");
 
     if (!canUseNpotTextures) {
       bool formatOk=false;
@@ -348,6 +354,9 @@ static bool generateTexture(const std::string &filename,
     }
   }
 
+  bool canUseMipmaps = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_framebuffer_object") ||
+                       OpenGlConfigManager::getInst().isExtensionSupported("GL_EXT_framebuffer_object");
+
   GLuint* textureNum = new GLuint[spriteNumber];
 
   glTexture.width=width;
@@ -385,6 +394,8 @@ static bool generateTexture(const std::string &filename,
 
   glGenTextures(spriteNumber, textureNum);  //FIXME: handle case where no memory is available to load texture
 
+  glEnable(GL_TEXTURE_2D);
+
   for(unsigned int i=0; i<spriteNumber; ++i) {
     glBindTexture(GL_TEXTURE_2D, textureNum[i]);
 
@@ -401,12 +412,27 @@ static bool generateTexture(const std::string &filename,
         glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE, dataForWidthSpriteTexture[i]);
       else
         glTexImage2D(GL_TEXTURE_2D, 0, GLFmt, width, height, 0, GLFmt, GL_UNSIGNED_BYTE, dataForWidthSpriteTexture[i]);
+
+      delete [] dataForWidthSpriteTexture[i];
     }
 
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
+
+    if (canUseMipmaps) {
+      glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR_MIPMAP_LINEAR);
+      glGenerateMipmap(GL_TEXTURE_2D);
+    }
+    else {
+      glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+    }
+
   }
 
+  glDisable(GL_TEXTURE_2D);
+
+  delete [] textureNum;
+  delete [] dataForWidthSpriteTexture;
+
   return true;
 }
 //====================================================================
@@ -493,6 +519,7 @@ void GlTextureManager::deleteTexture(const string& name) {
       for(unsigned int i=0; i<it2->second.spriteNumber; ++i)
         glDeleteTextures(1,&(it2->second.id[i]));
 
+      delete [] it2->second.id;
       it->second.erase(name);
     }
   }
