@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -83,9 +83,9 @@ GlVertexArrayManager::GlVertexArrayManager(GlGraphInputData *i):inputData(i),gra
 GlVertexArrayManager::~GlVertexArrayManager() {
   clearObservers();
   clearData();
-  static bool canUseVBO = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_vertex_buffer_object");
+  bool canUseVBO = OpenGlConfigManager::getInst().hasVertexBufferObject();
 
-  if (canUseVBO) {
+  if (canUseVBO && pointsVerticesVBO != 0) {
     glDeleteBuffers(1, &pointsVerticesVBO);
     glDeleteBuffers(1, &pointsColorsVBO);
     glDeleteBuffers(1, &linesVerticesVBO);
@@ -341,7 +341,7 @@ void GlVertexArrayManager::endRendering() {
 
   isBegin=false;
 
-  static bool canUseVBO = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_vertex_buffer_object");
+  static bool canUseVBO = OpenGlConfigManager::getInst().hasVertexBufferObject();
 
   if (canUseVBO && quadsVerticesVBO == 0) {
     glGenBuffers(1, &pointsVerticesVBO);
@@ -384,8 +384,6 @@ void GlVertexArrayManager::endRendering() {
     colorsUploadNeeded = false;
   }
 
-  OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
   glDisable(GL_LIGHTING);
   glDisable(GL_CULL_FACE);
   glDepthFunc(GL_LEQUAL);
@@ -393,101 +391,8 @@ void GlVertexArrayManager::endRendering() {
 
   glEnableClientState(GL_VERTEX_ARRAY);
 
-  //============ Selected graph elements rendering ============================
-
-  Color selectionColor=inputData->parameters->getSelectionColor();
-  glColor4ubv(reinterpret_cast<const GLubyte *>(&selectionColor));
-
-  // Selected edges point rendering
-  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedEdgesStencil(), 0xFFFF);
-  glPointSize(2);
-
-  if (!pointsEdgesSelectedRenderingIndexArray.empty()) {
-    if (canUseVBO && pointsVerticesUploaded) {
-      glBindBuffer(GL_ARRAY_BUFFER, pointsVerticesVBO);
-      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
-    }
-    else {
-      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(pointsCoordsArray));
-    }
-
-    glDrawElements(GL_POINTS, pointsEdgesSelectedRenderingIndexArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(pointsEdgesSelectedRenderingIndexArray));
-
-    if (canUseVBO) {
-      glBindBuffer(GL_ARRAY_BUFFER, 0);
-    }
-  }
-
-  // Selected nodes point rendering
-  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedNodesStencil(), 0xFFFF);
-  glPointSize(4);
-
-  if (!pointsNodesSelectedRenderingIndexArray.empty()) {
-    if (canUseVBO && pointsVerticesUploaded) {
-      glBindBuffer(GL_ARRAY_BUFFER, pointsVerticesVBO);
-      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
-    }
-    else {
-      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(pointsCoordsArray));
-    }
-
-    glDrawElements(GL_POINTS, pointsNodesSelectedRenderingIndexArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(pointsNodesSelectedRenderingIndexArray));
-
-    if (canUseVBO) {
-      glBindBuffer(GL_ARRAY_BUFFER, 0);
-    }
-  }
-
-  // Selected edges polyline rendering
-  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedEdgesStencil(), 0xFFFF);
-  glLineWidth(4);
-
-  if (!linesSelectedRenderingIndicesArray.empty()) {
-    if (canUseVBO && linesVerticesUploaded) {
-      glBindBuffer(GL_ARRAY_BUFFER, linesVerticesVBO);
-      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
-    }
-    else {
-      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(linesCoordsArray));
-    }
-
-    glDrawElements(GL_LINES, linesSelectedRenderingIndicesArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(linesSelectedRenderingIndicesArray));
-
-    if (canUseVBO) {
-      glBindBuffer(GL_ARRAY_BUFFER, 0);
-    }
-  }
-
-  // Selected edges quad rendering
-  if (!quadsSelectedRenderingIndicesArray.empty()) {
-    if (canUseVBO && quadsVerticesUploaded) {
-      glBindBuffer(GL_ARRAY_BUFFER, quadsVerticesVBO);
-      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
-    }
-    else {
-      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(quadsCoordsArray));
-    }
-
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
-    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-    glDrawElements(GL_TRIANGLES, quadsSelectedRenderingIndicesArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(quadsSelectedRenderingIndicesArray));
-    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
-    for (map<float, vector<GLuint> >::iterator it = quadsSelectedOutlineRenderingIndicesArray.begin(); it != quadsSelectedOutlineRenderingIndicesArray.end() ; ++it) {
-      glLineWidth(it->first);
-      glDrawElements(GL_LINES, it->second.size(), GL_UNSIGNED_INT, VECTOR_DATA(it->second));
-    }
-
-    if (canUseVBO) {
-      glBindBuffer(GL_ARRAY_BUFFER, 0);
-    }
-  }
-
   //============ Graph elements rendering ============================
 
-  OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
   glEnableClientState(GL_COLOR_ARRAY);
 
   // Edges point rendering
@@ -574,8 +479,6 @@ void GlVertexArrayManager::endRendering() {
     }
   }
 
-  OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
-
   // Edges quad rendering
   if (!quadsRenderingIndicesArray.empty()) {
     if (canUseVBO && quadsVerticesUploaded) {
@@ -605,15 +508,11 @@ void GlVertexArrayManager::endRendering() {
       }
     }
 
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-
     for (map<float, vector<GLuint> >::const_iterator it = quadsOutlineRenderingIndicesArray.begin(); it != quadsOutlineRenderingIndicesArray.end() ; ++it) {
       glLineWidth(it->first);
       glDrawElements(GL_LINES, it->second.size(), GL_UNSIGNED_INT, VECTOR_DATA(it->second));
     }
 
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
-
     if (canUseVBO && quadsColorsUploaded) {
       glBindBuffer(GL_ARRAY_BUFFER, quadsColorsVBO);
       glColorPointer(4, GL_UNSIGNED_BYTE, 0, BUFFER_OFFSET(0));
@@ -622,9 +521,7 @@ void GlVertexArrayManager::endRendering() {
       glColorPointer(4, GL_UNSIGNED_BYTE, 0, VECTOR_DATA(quadsColorsArray));
     }
 
-    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
     glDrawElements(GL_TRIANGLES, quadsRenderingIndicesArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(quadsRenderingIndicesArray));
-    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
 
     if (canUseVBO) {
       glBindBuffer(GL_ARRAY_BUFFER, 0);
@@ -632,6 +529,94 @@ void GlVertexArrayManager::endRendering() {
   }
 
   glDisableClientState(GL_COLOR_ARRAY);
+
+  //============ Selected graph elements rendering ============================
+
+  Color selectionColor=inputData->parameters->getSelectionColor();
+  glColor4ubv(reinterpret_cast<const GLubyte *>(&selectionColor));
+
+  // Selected edges point rendering
+  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedEdgesStencil(), 0xFFFF);
+  glPointSize(2);
+
+  if (!pointsEdgesSelectedRenderingIndexArray.empty()) {
+    if (canUseVBO && pointsVerticesUploaded) {
+      glBindBuffer(GL_ARRAY_BUFFER, pointsVerticesVBO);
+      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
+    }
+    else {
+      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(pointsCoordsArray));
+    }
+
+    glDrawElements(GL_POINTS, pointsEdgesSelectedRenderingIndexArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(pointsEdgesSelectedRenderingIndexArray));
+
+    if (canUseVBO) {
+      glBindBuffer(GL_ARRAY_BUFFER, 0);
+    }
+  }
+
+  // Selected nodes point rendering
+  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedNodesStencil(), 0xFFFF);
+  glPointSize(4);
+
+  if (!pointsNodesSelectedRenderingIndexArray.empty()) {
+    if (canUseVBO && pointsVerticesUploaded) {
+      glBindBuffer(GL_ARRAY_BUFFER, pointsVerticesVBO);
+      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
+    }
+    else {
+      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(pointsCoordsArray));
+    }
+
+    glDrawElements(GL_POINTS, pointsNodesSelectedRenderingIndexArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(pointsNodesSelectedRenderingIndexArray));
+
+    if (canUseVBO) {
+      glBindBuffer(GL_ARRAY_BUFFER, 0);
+    }
+  }
+
+  // Selected edges polyline rendering
+  glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedEdgesStencil(), 0xFFFF);
+  glLineWidth(4);
+
+  if (!linesSelectedRenderingIndicesArray.empty()) {
+    if (canUseVBO && linesVerticesUploaded) {
+      glBindBuffer(GL_ARRAY_BUFFER, linesVerticesVBO);
+      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
+    }
+    else {
+      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(linesCoordsArray));
+    }
+
+    glDrawElements(GL_LINES, linesSelectedRenderingIndicesArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(linesSelectedRenderingIndicesArray));
+
+    if (canUseVBO) {
+      glBindBuffer(GL_ARRAY_BUFFER, 0);
+    }
+  }
+
+  // Selected edges quad rendering
+  if (!quadsSelectedRenderingIndicesArray.empty()) {
+    if (canUseVBO && quadsVerticesUploaded) {
+      glBindBuffer(GL_ARRAY_BUFFER, quadsVerticesVBO);
+      glVertexPointer(3, GL_FLOAT, 0, BUFFER_OFFSET(0));
+    }
+    else {
+      glVertexPointer(3, GL_FLOAT, 0, VECTOR_DATA(quadsCoordsArray));
+    }
+
+    glDrawElements(GL_TRIANGLES, quadsSelectedRenderingIndicesArray.size(), GL_UNSIGNED_INT, VECTOR_DATA(quadsSelectedRenderingIndicesArray));
+
+    for (map<float, vector<GLuint> >::iterator it = quadsSelectedOutlineRenderingIndicesArray.begin(); it != quadsSelectedOutlineRenderingIndicesArray.end() ; ++it) {
+      glLineWidth(it->first);
+      glDrawElements(GL_LINES, it->second.size(), GL_UNSIGNED_INT, VECTOR_DATA(it->second));
+    }
+
+    if (canUseVBO) {
+      glBindBuffer(GL_ARRAY_BUFFER, 0);
+    }
+  }
+
   glStencilFunc(GL_LEQUAL, inputData->parameters->getSelectedEdgesStencil(), 0xFFFF);
   glDisableClientState(GL_VERTEX_ARRAY);
   glPointSize(1);
@@ -664,14 +649,13 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
   const Color &tgtColor = colorProperty->getNodeValue(tgt);
   const Color &borderColor = borderColorProperty->getEdgeValue(e);
 
-  if(toComputeAll || toComputeLayout) {
+  if(toComputeLayout) {
 
     size_t lastIndex=linesCoordsArray.size();
     gledge->getVertices(inputData,linesCoordsArray);
     size_t numberOfVertices=linesCoordsArray.size()-lastIndex;
 
     vector<Coord> vertices;
-    vector<Color> colors;
 
     if(numberOfVertices!=0) {
       edgeToLineIndexVector[gledge->id]=pair<unsigned int,unsigned int>(linesIndexArray.size(),linesIndexCountArray.size());
@@ -681,12 +665,10 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
         vertices.push_back(linesCoordsArray[lastIndex+i]);
       }
 
-      gledge->getColors(inputData, vertices,colors);
-      linesColorsArray.insert(linesColorsArray.end(), colors.begin(), colors.end());
       linesIndexCountArray.push_back(numberOfVertices);
 
       pointsCoordsArray.push_back(linesCoordsArray[lastIndex]);
-      pointsColorsArray.push_back(linesColorsArray[lastIndex]);
+
       edgeToPointIndexVector[gledge->id]=pointsCoordsArray.size()-1;
 
       Size edgeSize;
@@ -717,13 +699,10 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
       vector<Coord> quadVertices;
       buildCurvePoints(vertices, edgeSizes, layoutProperty->getNodeValue(src), layoutProperty->getNodeValue(tgt), quadVertices);
 
-      vector<Coord> centerLine;
-      centerLine.reserve(quadVertices.size()/2);
       vector<GLuint> quadBottomOutlineIndices;
       vector<GLuint> quadTopOutlineIndices;
 
       for (size_t i = 0 ; i < quadVertices.size() / 2 ; ++i) {
-        centerLine.push_back((quadVertices[2*i]+quadVertices[2*i+1])/2.f);
         quadBottomOutlineIndices.push_back(lastQuadIndex+2*i);
         quadTopOutlineIndices.push_back(lastQuadIndex+2*i+1);
       }
@@ -731,23 +710,6 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
       quadsBottomOutlineIndexArray.push_back(quadBottomOutlineIndices);
       quadsTopOutlineIndexArray.push_back(quadTopOutlineIndices);
 
-      vector<Color> colors;
-      getColors(&centerLine[0], centerLine.size(), srcColor, tgtColor,colors);
-
-      for (size_t i = 0 ; i < colors.size() ; ++i) {
-        if (inputData->parameters->isEdgeColorInterpolate()) {
-          quadsColorsArray.push_back(colors[i]);
-          quadsColorsArray.push_back(colors[i]);
-        }
-        else {
-          quadsColorsArray.push_back(edgeColor);
-          quadsColorsArray.push_back(edgeColor);
-        }
-
-        quadsOutlineColorsArray.push_back(borderColor);
-        quadsOutlineColorsArray.push_back(borderColor);
-      }
-
       quadsCoordsArray.insert(quadsCoordsArray.end(), quadVertices.begin(), quadVertices.end());
       quadsIndexCountArray.push_back(quadVertices.size());
 
@@ -767,7 +729,8 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
     }
 
   }
-  else {
+
+  if (toComputeColor) {
     size_t lastIndex=linesColorsArray.size();
     pair<unsigned int,unsigned int> index=edgeToLineIndexVector[gledge->id];
     pair<unsigned int,unsigned int> indexQuad=edgeToQuadIndexVector[gledge->id];
@@ -811,11 +774,13 @@ void GlVertexArrayManager::addEdge(GlEdge *gledge) {
 }
 
 void GlVertexArrayManager::addNode(GlNode *node) {
-  if(toComputeAll || toComputeLayout) {
-    node->getPointAndColor(inputData,pointsCoordsArray,pointsColorsArray);
+  if(toComputeLayout) {
+    vector<Color> tmp;
+    node->getPointAndColor(inputData,pointsCoordsArray, tmp);
     nodeToPointIndexVector[node->id]=pointsCoordsArray.size()-1;
   }
-  else {
+
+  if (toComputeColor) {
     node->getColor(inputData,pointsColorsArray);
   }
 }
@@ -970,54 +935,60 @@ void GlVertexArrayManager::propertyValueChanged(PropertyInterface *property) {
 
 void GlVertexArrayManager::clearLayoutData() {
   toComputeLayout=true;
+  verticesUploadNeeded=true;
+
   linesCoordsArray.clear();
   pointsCoordsArray.clear();
   quadsCoordsArray.clear();
-  vectorLayoutSizeInit=false;
-  verticesUploadNeeded=true;
-}
 
-void GlVertexArrayManager::clearColorData() {
-  toComputeColor=true;
-  colorsUploadNeeded=true;
-  linesColorsArray.clear();
-  pointsColorsArray.clear();
-  quadsColorsArray.clear();
-  quadsOutlineColorsArray.clear();
-  vectorColorSizeInit=false;
-}
-
-void GlVertexArrayManager::clearData() {
-  toComputeAll=true;
-  verticesUploadNeeded=true;
-  colorsUploadNeeded=true;
-  linesCoordsArray.clear();
-  linesColorsArray.clear();
   linesIndexArray.clear();
   linesIndexCountArray.clear();
-  edgeToLineIndexVector.clear();
-  edgeToQuadIndexVector.clear();
-  edgeToTopOutlineIndexVector.clear();
-  edgeToBottomOulineIndexVector.clear();
 
-  quadsCoordsArray.clear();
-  quadsColorsArray.clear();
-  quadsOutlineColorsArray.clear();
+  if (!edgeToLineIndexVector.empty())
+    edgeToLineIndexVector.clear();
+
+  if (!edgeToQuadIndexVector.empty())
+    edgeToQuadIndexVector.clear();
+
+  if (!edgeToTopOutlineIndexVector.empty())
+    edgeToTopOutlineIndexVector.clear();
+
+  if (!edgeToBottomOulineIndexVector.empty())
+    edgeToBottomOulineIndexVector.clear();
+
   quadsIndexArray.clear();
   quadsIndexCountArray.clear();
   quadsTopOutlineIndexArray.clear();
   quadsBottomOutlineIndexArray.clear();
 
-  pointsCoordsArray.clear();
-  pointsColorsArray.clear();
-  edgeToPointIndexVector.clear();
-  nodeToPointIndexVector.clear();
+  if (!edgeToPointIndexVector.empty())
+    edgeToPointIndexVector.clear();
+
+  if (!nodeToPointIndexVector.empty())
+    nodeToPointIndexVector.clear();
 
   vectorLayoutSizeInit=false;
-  vectorColorSizeInit=false;
   vectorIndexSizeInit=false;
 }
 
+void GlVertexArrayManager::clearColorData() {
+  toComputeColor=true;
+  colorsUploadNeeded=true;
+
+  linesColorsArray.clear();
+  pointsColorsArray.clear();
+  quadsColorsArray.clear();
+  quadsOutlineColorsArray.clear();
+
+  vectorColorSizeInit=false;
+}
+
+void GlVertexArrayManager::clearData() {
+  toComputeAll=true;
+  clearLayoutData();
+  clearColorData();
+}
+
 void GlVertexArrayManager::initObservers() {
   if(!graph)
     return;
