@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -103,6 +103,9 @@ tlp::View *TulipViewsManager::addView(const std::string &viewName, tlp::Graph *g
     workspace->addPanel(view);
   }
   else {
+
+    graph->addListener(this);
+
     model->addGraph(graph);
 
     view = PluginLister::instance()->getPluginObject<View>(viewName,NULL);
@@ -122,6 +125,9 @@ tlp::View *TulipViewsManager::addView(const std::string &viewName, tlp::Graph *g
     setViewVisible(view, show);
     view->draw();
     QApplication::processEvents();
+
+
+
   }
 
   connect(view, SIGNAL(destroyed(QObject *)), this, SLOT(viewDestroyed(QObject*)));
@@ -289,3 +295,10 @@ void TulipViewsManager::setViewPos(tlp::View *view, int x, int y) {
     QApplication::processEvents();
   }
 }
+
+void TulipViewsManager::treatEvent(const tlp::Event& ev) {
+  if (ev.type() == Event::TLP_DELETE) {
+    Graph *g = static_cast<Graph*>(ev.sender());
+    closeViewsRelatedToGraph(g);
+  }
+}
