@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -461,7 +461,8 @@ PythonCodeEditor::PythonCodeEditor(QWidget *parent) : QPlainTextEdit(parent), _h
   _currentFont.setPointSize(8);
 #endif
 
-  setStyleSheet("QFrame { background-color: white;}");
+  setStyleSheet("QFrame { background-color: white; }"
+                "QPlainTextEdit { selection-background-color: #C0C0C0; }");
 
   format.setFont(_currentFont);
   setCurrentCharFormat(format);
@@ -1534,7 +1535,7 @@ bool PythonCodeEditor::loadCodeFromFile(const QString &filePath) {
   QString scriptCode;
 
   while (!file.atEnd()) {
-    scriptCode += file.readLine();
+    scriptCode += QString::fromUtf8(file.readLine().data());
   }
 
   file.close();
@@ -1563,6 +1564,7 @@ bool PythonCodeEditor::saveCodeToFile() {
 
   if (getFileName() == fileInfo.absoluteFilePath() && file.open(QIODevice::WriteOnly | QIODevice::Text)) {
     QTextStream out(&file);
+    out.setCodec("UTF-8");
     out << getCleanCode();
     file.close();
     QFileInfo fileInfo(file);
@@ -1578,3 +1580,14 @@ void PythonCodeEditor::scrollToLine(int line) {
   setTextCursor(QTextCursor(block));
   centerCursor();
 }
+
+void PythonCodeEditor::setPlainText(const QString &text) {
+  QPlainTextEdit::setPlainText(text);
+  QTextCursor cursor = textCursor();
+  selectAll();
+  QTextCharFormat format = currentCharFormat();
+  format.setFont(_currentFont);
+  setCurrentCharFormat(format);
+  setTextCursor(cursor);
+  updateTabStopWidth();
+}
