@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -34,6 +34,7 @@
 
 #include <tulip/TulipRelease.h>
 #include <tulip/TlpTools.h>
+#include <tulip/PythonVersionChecker.h>
 
 #include <cstdio>
 #ifndef WIN32
@@ -163,7 +164,7 @@ const QString PythonInterpreter::pythonPluginsPathHome(QDir::homePath()+"/.Tulip
 const char PythonInterpreter::pythonReservedCharacters[] = {
   '#', '%', '/', '+', '-', '&', '*', '<', '>',
   '|', '~', '^', '=', '!', '\'', '\"', '{', '}',
-  '(', ')', '[', ']', '.', 0
+  '(', ')', '[', ']', '.', ':', '@', 0
 };
 
 const char *PythonInterpreter::pythonKeywords[] = {
@@ -220,6 +221,27 @@ PythonInterpreter::PythonInterpreter() : _wasInit(false), _runningScript(false),
 
     Py_OptimizeFlag = 1;
     Py_NoSiteFlag = 1;
+
+    // Fix for GDB debugging on windows when compiling with MinGW.
+    // GDB contains an embedded Python interpreter that messes up Python Home value.
+    // When Tulip is compiled with a version of Python different from the one embedded in GDB,
+    // it crashes at startup when running it through GDB.
+    // So reset correct one to be able to debug it.
+#ifdef __MINGW32__
+    QString pythonHome = PythonVersionChecker::getPythonHome();
+
+    if (!pythonHome.isEmpty()) {
+#if PY_MAJOR_VERSION >= 3
+      static std::wstring pythonHomeWString = pythonHome.toStdWString();
+      Py_SetPythonHome(const_cast<wchar_t*>(pythonHomeWString.c_str()));
+#else
+      static std::string pythonHomeString = pythonHome.toStdString();
+      Py_SetPythonHome(const_cast<char*>(pythonHomeString.c_str()));
+#endif
+    }
+
+#endif
+
     Py_InitializeEx(0);
 
     PySys_SetArgv(argc, argv);
@@ -327,14 +349,13 @@ PythonInterpreter::PythonInterpreter() : _wasInit(false), _runningScript(false),
       runString("import sys;"
                 "import consoleutils;"
                 "import tuliputils;"
-                "sys.stdout = consoleutils.ConsoleOutput(False);"
-                "sys.stderr = consoleutils.ConsoleOutput(True);"
-                "sys.stdin = consoleutils.ConsoleInput()\n");
+                "sys.stdout = None;"
+                "sys.stderr = None;"
+                "sys.stdin = None\n");
 
       // Try to import site package manually otherwise Py_InitializeEx can crash if Py_NoSiteFlag is not set
       // and if the site module is not present on the host system
       // Disable output while trying to import the module to not confuse the user
-      outputActivated = false;
       runString("import site");
 #if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 3
       runString("site.main()");
@@ -343,7 +364,6 @@ PythonInterpreter::PythonInterpreter() : _wasInit(false), _runningScript(false),
       runString("from tulip import *");
       runString("from tulipogl import *");
       runString("from tulipgui import *");
-      outputActivated = true;
 
 #ifndef _MSC_VER
       loadTulipPythonPluginsFromDefaultDirs();
@@ -351,6 +371,11 @@ PythonInterpreter::PythonInterpreter() : _wasInit(false), _runningScript(false),
 
       runString(printObjectDictFunction);
       runString(printObjectClassFunction);
+
+      runString("sys.stdout = consoleutils.ConsoleOutput(False);"
+                "sys.stderr = consoleutils.ConsoleOutput(True);"
+                "sys.stdin = consoleutils.ConsoleInput()\n");
+
     }
 
     PyEval_SetTrace(tracefunc, NULL);
@@ -389,19 +414,23 @@ PythonInterpreter::~PythonInterpreter() {
     consoleOuputString = "";
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
-    // This is a hack to prevent segfaults when the PyQt4 module has been imported
-    // during the Python session. Seems there is some garbage collection issue
-    // on Qt objects wrapped by SIP. After looking at the SIP source code, the
-    // segfault is raised when the sipQtSupport->qt_find_sipslot function is called.
-    // So reset the sipQtSupport pointer to NULL, this way the problematic function will no
-    // more be called when the Python interpreter is finalized.
-    setOutputEnabled(false);
-    runString("sys.stdout.write(sip.__file__)");
-    QString sipModulePath = consoleOuputString;
-    sipQtAPI **sipQtSupport = reinterpret_cast<sipQtAPI **>(QLibrary::resolve(sipModulePath, "sipQtSupport"));
 
-    if (sipQtSupport)
-      *sipQtSupport = NULL;
+    if (QApplication::instance()) {
+
+      // This is a hack to prevent segfaults when the PyQt4 module has been imported
+      // during the Python session. Seems there is some garbage collection issue
+      // on Qt objects wrapped by SIP. After looking at the SIP source code, the
+      // segfault is raised when the sipQtSupport->qt_find_sipslot function is called.
+      // So reset the sipQtSupport pointer to NULL, this way the problematic function will no
+      // more be called when the Python interpreter is finalized.
+      setOutputEnabled(false);
+      runString("import sip; sys.stdout.write(sip.__file__)");
+      QString sipModulePath = consoleOuputString;
+      sipQtAPI **sipQtSupport = reinterpret_cast<sipQtAPI **>(QLibrary::resolve(sipModulePath, "sipQtSupport"));
+
+      if (sipQtSupport)
+        *sipQtSupport = NULL;
+    }
 
 #endif
 
@@ -492,7 +521,7 @@ bool PythonInterpreter::importModule(const QString &moduleName) {
 bool PythonInterpreter::registerNewModuleFromString(const QString &moduleName, const QString &moduleSrcCode) {
   bool ret = true;
   holdGIL();
-  PyObject *pycomp = Py_CompileString(moduleSrcCode.toStdString().c_str(),QString(moduleName + ".py").toStdString().c_str(), Py_file_input);
+  PyObject *pycomp = Py_CompileString(moduleSrcCode.toUtf8().data(), QString(moduleName + ".py").toStdString().c_str(), Py_file_input);
 
   if (pycomp == NULL) {
     PyErr_Print();
