@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -133,10 +133,16 @@ void ExportSvg::addLabel(const string &type, const string &label, const Color &l
   if(!label.empty()) {
     _res.writeStartElement("text");
     _res.writeAttribute("x", QString::number(coord.getX()));
-    _res.writeAttribute("y", QString::number(-coord.getY()));
 
     if (type == "node")
-      _res.writeAttribute("font-size", QString::number(min(size.getW()*1.2,size.getH()*1.2)/label.length()));
+      // empirically adjust to font-size/3 to ensure centering
+      _res.writeAttribute("y", QString::number(-(coord.getY() -
+                          (size.getW() * 1.2)/ (3 * label.length()))));
+    else
+      _res.writeAttribute("y", QString::number(-coord.getY()));
+
+    if (type == "node")
+      _res.writeAttribute("font-size", QString::number((size.getW() * 1.2) /label.length()));
     else if (type == "edge")
       _res.writeAttribute("font-size", QString::number(((size.getW()+size.getH())/label.length())+8));
 
