@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,6 @@
 #include <tulip/ColorProperty.h>
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
@@ -91,9 +90,7 @@ void Cone::draw(node n, float) {
     GlTextureManager::getInst().activateTexture(texturePath + texFile);
   }
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
   GlDisplayListManager::getInst().callDisplayList("Cone_cone");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
 
   GlTextureManager::getInst().desactivateTexture();
 }
@@ -142,6 +139,7 @@ public:
 
   virtual void draw(edge e, node /*n*/, const Color& glyphColor,const Color &/*borderColor*/, float /*lod*/) {
     glEnable(GL_LIGHTING);
+    glRotatef(90.0f, 0.0f, 1.0f, 0.0f);
 
     if (GlDisplayListManager::getInst().beginNewDisplayList("Cone_cone")) {
       drawCone();
@@ -157,9 +155,7 @@ public:
       GlTextureManager::getInst().activateTexture(texturePath + texFile);
     }
 
-    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
     GlDisplayListManager::getInst().callDisplayList("Cone_cone");
-    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
     GlTextureManager::getInst().desactivateTexture();
   }
 };
