@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,6 @@
 #include <tulip/ColorProperty.h>
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
@@ -93,9 +92,7 @@ void Cylinder::draw(node n, float) {
     GlTextureManager::getInst().activateTexture(texturePath + texFile);
   }
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
   GlDisplayListManager::getInst().callDisplayList("Cylinder_cylinder");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
   GlTextureManager::getInst().desactivateTexture();
 }
 Coord Cylinder::getAnchor(const Coord &vector) const {
@@ -130,6 +127,7 @@ public:
 
   void draw(edge, node n, const Color& glyphColor, const Color&, float) {
     glEnable(GL_LIGHTING);
+    glRotatef(90.0f, 0.0f, 1.0f, 0.0f);
 
     if (GlDisplayListManager::getInst().beginNewDisplayList("Cylinder_cylinder")) {
       drawCylinder();
@@ -145,9 +143,7 @@ public:
       GlTextureManager::getInst().activateTexture(texturePath + texFile);
     }
 
-    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
     GlDisplayListManager::getInst().callDisplayList("Cylinder_cylinder");
-    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
     GlTextureManager::getInst().desactivateTexture();
   }
 };
