@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -23,7 +23,6 @@
 #include <tulip/GlShaderProgram.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlGraphInputData.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlTools.h>
 #include <tulip/TulipViewSettings.h>
 
@@ -392,13 +391,11 @@ void RoundedBox::draw(node n, float lod) {
 
     glVertexPointer(2, GL_FLOAT, 2 * sizeof(float), outlineVeticesData);
 
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
     roundedBoxOutlineShader->activate();
     roundedBoxOutlineShader->setUniformFloat("boxWidth", size[0]);
     roundedBoxOutlineShader->setUniformFloat("boxHeight", size[1]);
     glDrawArrays(GL_LINE_STRIP_ADJACENCY_EXT, 0, 4);
     roundedBoxOutlineShader->desactivate();
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
 
     glDisableClientState(GL_VERTEX_ARRAY);
   }
