@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -159,8 +159,6 @@ static void drawGlyph(const Color& glyphColor, const string& texture,
     GlTextureManager::getInst().activateTexture(texturePath + texture);
   }
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-
   if (canUseVBO) {
     glEnableClientState(GL_VERTEX_ARRAY);
     glEnableClientState(GL_NORMAL_ARRAY);
@@ -192,8 +190,6 @@ static void drawGlyph(const Color& glyphColor, const string& texture,
     GlDisplayListManager::getInst().callDisplayList("Sphere_sphere");
   }
 
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-
   GlTextureManager::getInst().desactivateTexture();
 }
 
