@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -276,7 +276,7 @@ public :
       }
 
       // check other parameters
-      Size nSize(0.1,0.1,0);
+      Size nSize(0.1f, 0.1f, 0);
 
       for(; i < nbTokens; ++i) {
         if (tokens[i] == "x_fact") {
@@ -383,7 +383,7 @@ public :
       return false;
     }
 
-    std::ifstream in(filename.c_str());
+    std::istream *in = tlp::getInputFileStream(filename.c_str());
 
     labels   = graph->getProperty<StringProperty>("viewLabel");
     weights  = graph->getProperty<DoubleProperty>("weights");
@@ -393,7 +393,7 @@ public :
     // because when node's layout is provided
     // x,y,z coordinates are restricted to [0.0, 1.0]
     // arbitrary set default size for nodes to (0.01, 0.01, 0)
-    sizes->setAllNodeValue(Size(0.01, 0.01, 0.0));
+    sizes->setAllNodeValue(Size(0.01f, 0.01f, 0.0f));
 
     stringstream errors;
     size_t lineNumber = 0;
@@ -405,7 +405,7 @@ public :
 
     string line;
 
-    while (!in.eof() && std::getline(in, line)) {
+    while (!in->eof() && std::getline(*in, line)) {
 
       ++lineNumber;
 
@@ -417,14 +417,18 @@ public :
           pluginProgress->setError(errors.str());
         }
 
+        delete in;
         return false;
       }
 
       if (pluginProgress && ((lineNumber % 100) == 0) &&
-          (pluginProgress->progress(lineNumber, 3 * nbNodes) != TLP_CONTINUE))
+          (pluginProgress->progress(lineNumber, 3 * nbNodes) != TLP_CONTINUE)) {
+        delete in;
         return false;
+      }
     }
 
+    delete in;
     return true;
   }
 };
