@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -992,7 +992,7 @@ public :
       return false;
     }
 
-    std::ifstream in(filename.c_str());
+    std::istream *in = tlp::getInputFileStream(filename.c_str());
 
     stringstream errors;
     size_t lineNumber = 0;
@@ -1009,7 +1009,7 @@ public :
 
     std::string line;
 
-    while (!in.eof() && std::getline(in, line)) {
+    while (!in->eof() && std::getline(*in, line)) {
       bool result = false;
 
       ++lineNumber;
@@ -1108,15 +1108,18 @@ public :
           pluginProgress->setError(errors.str());
         }
 
+        delete in;
         return false;
       }
 
       if (pluginProgress && ((lineNumber % 100) == 0) &&
           (pluginProgress->progress(lineNumber, 3 * nbNodes) != TLP_CONTINUE)) {
+        delete in;
         return false;
       }
     }
 
+    delete in;
     return true;
   }
 };
