@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -527,6 +527,7 @@ void NeighborhoodHighlighter::updateGlNeighborhoodGraph() {
   glNeighborhoodGraphInputData->setElementColor(neighborhoodGraphColors);
   glNeighborhoodGraphInputData->setElementLabel(originalInputData->getElementLabel());
   glNeighborhoodGraphInputData->setElementLabelColor(originalInputData->getElementLabelColor());
+  glNeighborhoodGraphInputData->setElementLabelBorderColor(originalInputData->getElementLabelBorderColor());
   glNeighborhoodGraphInputData->setElementLabelPosition(originalInputData->getElementLabelPosition());
   glNeighborhoodGraphInputData->setElementLayout(neighborhoodGraphLayout);
   glNeighborhoodGraphInputData->setElementRotation(originalInputData->getElementRotation());
