@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -135,6 +135,9 @@ bool Grip::run() {
       }
     }
     else {
+      // initialize a random sequence according the given seed
+      tlp::initRandomSequence();
+
       misf = new MISFiltering(currentGraph);
       computeOrdering();
       init();
