@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -306,8 +306,8 @@ int RectanglePacking::calculOfNumberOptimalRepositionnedRectangles(const char *
 void RectanglePacking::defaultPositionRestOfRectangles(vector<Rectangle<float> >::iterator itlim, vector<Rectangle<float> >::iterator itend) {
 
   vector<Rectangle<float> >::iterator itr;
-  bool boolWidth;
-  bool boolHeight;
+  bool boolWidth = false;
+  bool boolHeight = false;
   float heightTemp = 0;
   float widthTemp = 0;
 
