@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -361,8 +361,8 @@ bool LouvainClustering::run() {
   if(dataSet!=NULL)
     dataSet->get("metric",metric);
 
-  //Init RNG seed
-  srand ((time(NULL)));
+  // initialize a random sequence according the given seed
+  tlp::initRandomSequence();
   //Init Quotient graph
   createQuotient();
 
