@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -29,8 +29,7 @@ public:
   bool run();
   bool check(std::string &);
 private:
-  double getNodeValue(const tlp::node n);
-  tlp::DoubleProperty* leafMetric;
+  double getNodeValue(const tlp::node n, tlp::DoubleProperty* leafMetric);
 };
 
 #endif
