@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -27,6 +27,9 @@ RandomMetric::RandomMetric(const tlp::PluginContext* context):DoubleAlgorithm(co
 {}
 //===========================================
 bool RandomMetric::run() {
+  // initialize a random sequence according the given seed
+  tlp::initRandomSequence();
+
   node n;
   forEach(n, graph->getNodes())
   result->setNodeValue(n, (double)rand() / double(RAND_MAX));
