@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -19,9 +19,10 @@
 #ifndef GRAPHHIERARCHIESEDITOR_H
 #define GRAPHHIERARCHIESEDITOR_H
 
+#include <tulip/TreeViewComboBox.h>
+
 #include <QWidget>
 #include <QModelIndex>
-#include <QTreeView>
 
 class QAbstractButton;
 
@@ -34,7 +35,7 @@ namespace Ui {
 class GraphHierarchiesEditorData;
 }
 
-class CustomTreeView : public QTreeView {
+class CustomTreeView : public DeferredUpdateTreeView {
 
   Q_OBJECT
 
