@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -27,11 +27,12 @@
 #include <tulip/TulipRelease.h>
 #include <tulip/TlpTools.h>
 
-DocumentationNavigator::DocumentationNavigator(): QDialog() {
+DocumentationNavigator::DocumentationNavigator(): QDialog(NULL, Qt::Window) {
   setWindowIcon(QIcon(":/logo32x32.ico"));
   setWindowTitle(QString("Tulip ") + TULIP_MM_VERSION + " documentation");
 
   QVBoxLayout* vLayout = new QVBoxLayout(this);
+  vLayout->setContentsMargins(0,0,0,0);
   tabWidget = new QTabWidget(this);
   vLayout->addWidget(tabWidget);
   QToolBar* tb = new QToolBar();
