@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -35,7 +35,7 @@
 #include <tulip/GraphHierarchiesModel.h>
 #include "ui_GraphHierarchiesEditor.h"
 
-CustomTreeView::CustomTreeView(QWidget *parent) : QTreeView(parent) {
+CustomTreeView::CustomTreeView(QWidget *parent) : DeferredUpdateTreeView(parent) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
   header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 #else
@@ -304,7 +304,10 @@ void GraphHierarchiesEditor::exportGraph() {
 }
 
 void GraphHierarchiesEditor::renameGraph() {
-  _ui->hierarchiesTree->edit(_contextIndex);
+  QModelIndex nameIndex =
+    _ui->hierarchiesTree->model()->index(_contextIndex.row(), 0,
+                                         _contextIndex.parent());
+  _ui->hierarchiesTree->edit(nameIndex);
 }
 
 void GraphHierarchiesEditor::saveGraphHierarchyInTlpFile() {
