@@ -4,7 +4,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -68,6 +68,14 @@ using namespace std;
 
 GraphPerspective::GraphPerspective(const tlp::PluginContext* c): Perspective(c), _ui(NULL), _graphs(new GraphHierarchiesModel(this)), _recentDocumentsSettingsKey("perspective/recent_files"), _logger(NULL) {
   Q_INIT_RESOURCE(GraphPerspective);
+
+  if (c && ((PerspectiveContext *) c)->parameters.contains("gui_testing")) {
+    tlp::setGuiTestingMode(true);
+    // we must ensure that choosing a file is relative to
+    // the current directory to allow to run the gui tests
+    // from any relative unit_test/gui directory
+    _lastOpenLocation = QDir::currentPath();
+  }
 }
 
 void GraphPerspective::reserveDefaultProperties() {
@@ -234,6 +242,9 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   _ui->splitModeButton->setEnabled(false);
   _ui->splitModeButton->hide();
   _ui->workspace->setSplitModeSwitch(_ui->splitModeButton);
+  _ui->splitHorizontalModeButton->setEnabled(false);
+  _ui->splitHorizontalModeButton->hide();
+  _ui->workspace->setSplitHorizontalModeSwitch(_ui->splitHorizontalModeButton);
   _ui->split3ModeButton->setEnabled(false);
   _ui->split3ModeButton->hide();
   _ui->workspace->setSplit3ModeSwitch(_ui->split3ModeButton);
@@ -416,11 +427,17 @@ void GraphPerspective::exportGraph(Graph* g) {
 
   std::ostream *os;
   std::string filename = (exportFile = wizard.outputFile()).toUtf8().data();
+  std::string exportPluginName = wizard.algorithm().toStdString();
 
   if (filename.rfind(".gz") == (filename.length() - 3))
-    os = tlp::getOgzstream(filename.c_str());
-  else
-    os = new std::ofstream(filename.c_str());
+    os = tlp::getOgzstream(filename);
+  else {
+    if (exportPluginName == "TLPB Export")
+      os = tlp::getOutputFileStream(filename,
+                                    std::ios::out | std::ios::binary);
+    else
+      os = tlp::getOutputFileStream(filename);
+  }
 
   if (os->fail()) {
     QMessageBox::critical(_mainWindow,trUtf8("File error"),trUtf8("Cannot open output file for writing: ") + wizard.outputFile());
@@ -430,7 +447,6 @@ void GraphPerspective::exportGraph(Graph* g) {
 
   DataSet data = wizard.parameters();
   PluginProgress* prg = progress(NoProgressOption);
-  std::string exportPluginName = wizard.algorithm().toStdString();
   prg->setTitle(exportPluginName);
   bool result = tlp::exportGraph(g,*os,exportPluginName,data,prg);
   delete os;
@@ -463,13 +479,13 @@ void GraphPerspective::saveGraphHierarchyInTlpFile(Graph *g) {
     std::ostream *os;
 
     if (filename.rfind(".tlp.gz") == (filename.length() - 7))
-      os = tlp::getOgzstream(filename.c_str());
+      os = tlp::getOgzstream(filename);
     else {
-      if (filename.rfind(".tlp") == std::string::npos)
+      if (filename.rfind(".tlp") != (filename.length() - 4))
         // force file extension
         filename += ".tlp";
 
-      os = new std::ofstream(filename.c_str());
+      os = tlp::getOutputFileStream(filename);
     }
 
     if (os->fail()) {
@@ -514,10 +530,9 @@ void GraphPerspective::importGraph(const std::string& module,
     std::string name;
 
     if (!g->getAttribute<std::string>("name", name)) {
-      QString n = QString(module.c_str()) + " - " +
-                  QString::fromUtf8(data.toString().c_str());
+      QString n = tlp::tlpStringToQString(module) + " - " + tlp::tlpStringToQString(data.toString());
       n.replace(QRegExp("[\\w]*::"),""); // remove words before "::"
-      g->setAttribute<std::string>("name", std::string(n.toUtf8().data()));
+      g->setName(tlp::QStringToTlpString(n));
     }
   }
   else {
@@ -534,13 +549,12 @@ void GraphPerspective::importGraph() {
 
   if (wizard.exec() == QDialog::Accepted) {
     DataSet data = wizard.parameters();
-    std::string importPluginName = wizard.algorithm().toStdString();
-    importGraph(importPluginName, data);
+    importGraph(tlp::QStringToTlpString(wizard.algorithm()), data);
   }
 }
 
 void GraphPerspective::createPanel(tlp::Graph* g) {
-  if (_graphs->size() == 0)
+  if (_graphs->empty())
     return;
 
   PanelSelectionWizard wizard(_graphs,_mainWindow);
@@ -654,9 +668,14 @@ void GraphPerspective::open(QString fileName) {
 
   if(!fileName.isEmpty()) {
     QFileInfo fileInfo(fileName);
-    _lastOpenLocation = fileInfo.absolutePath();
 
-    foreach(std::string extension, modules.keys()) {
+    // we must ensure that choosing a file is relative to
+    // the current directory to allow to run the gui tests
+    // from any relative unit_test/gui directory
+    if (!tlp::inGuiTestingMode())
+      _lastOpenLocation = fileInfo.absolutePath();
+
+    foreach(const std::string& extension, modules.keys()) {
       if (fileName.endsWith(".tlpx")) {
         openProjectFile(fileName);
         TulipSettings::instance().addToRecentDocuments(fileInfo.absoluteFilePath());
@@ -677,8 +696,7 @@ void GraphPerspective::open(QString fileName) {
 void GraphPerspective::openProjectFile(const QString &path) {
   if (_graphs->empty()) {
     PluginProgress* prg = progress(NoProgressOption);
-    delete _project;
-    _project = TulipProject::openProject(path,prg);
+    _project->openProjectFile(path,prg);
     QMap<QString,tlp::Graph*> rootIds = _graphs->readProject(_project,prg);
     _ui->workspace->readProject(_project,rootIds,prg);
     _ui->developFrame->setProject(_project);
@@ -867,7 +885,7 @@ void GraphPerspective::group() {
     changeGraph = true;
   }
 
-  graph->createMetaNode(groupedNodes);
+  graph->createMetaNode(groupedNodes, false);
 
   selection->setAllNodeValue(false);
   selection->setAllEdgeValue(false);
@@ -956,6 +974,7 @@ void GraphPerspective::currentGraphChanged(Graph *graph) {
   _ui->actionExport->setEnabled(enabled);
   _ui->singleModeButton->setEnabled(enabled);
   _ui->splitModeButton->setEnabled(enabled);
+  _ui->splitHorizontalModeButton->setEnabled(enabled);
   _ui->split3ModeButton->setEnabled(enabled);
   _ui->split32ModeButton->setEnabled(enabled);
   _ui->split33ModeButton->setEnabled(enabled);
@@ -995,10 +1014,14 @@ void GraphPerspective::CSVImport() {
 
   CSVImportWizard wizard(_mainWindow);
 
-  if (mustDeleteGraph)
+  if (mustDeleteGraph) {
     wizard.setWindowTitle("Import CSV data into a new graph");
-  else
-    wizard.setWindowTitle(QString("Import CSV data into graph: ") +  g->getName().c_str());
+    wizard.setButtonText(QWizard::FinishButton, QString("Import into a new graph"));
+  }
+  else {
+    wizard.setWindowTitle(QString("Import CSV data into current graph: ") +  g->getName().c_str());
+    wizard.setButtonText(QWizard::FinishButton, QString("Import into current graph"));
+  }
 
   wizard.setGraph(g);
   g->push();
@@ -1032,6 +1055,9 @@ void GraphPerspective::CSVImport() {
 }
 
 void GraphPerspective::showStartPanels(Graph *g) {
+  if (TulipSettings::instance().displayDefaultViews() == false)
+    return;
+
   // expose mode is not safe to add a new panel
   // so hide it if needed
   _ui->workspace->hideExposeMode();
