@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -79,7 +79,7 @@ void GraphPerspectiveLogger::log(QtMsgType type, const char* msg) {
   // on some windows systems
   // "No errors." messages may be logged coming from QGLShader::link
   // we try to avoid them
-  if (QString(msg).indexOf("No errors."))
+  if (QString(msg).indexOf("No errors.") != -1)
     return;
 
   if (type == QtFatalMsg) {
