@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -338,9 +338,13 @@ void SearchWidget::search() {
   node n;
   edge e;
 
-  if (_ui->selectionModeCombo->currentIndex() == 0) // replace current selection
+  QString searchOpDescription;
+
+  if (_ui->selectionModeCombo->currentIndex() == 0) {// replace current selection
     output->copy(result);
-  else if (_ui->selectionModeCombo->currentIndex() == 1) { // add to current selection
+    searchOpDescription = "found";
+  }
+  else if (_ui->selectionModeCombo->currentIndex() == 1) {   // add to current selection
     if (onNodes) {
       forEach(n,result->getNodesEqualTo(true)) {
         output->setNodeValue(n,true);
@@ -352,6 +356,8 @@ void SearchWidget::search() {
         output->setEdgeValue(e,true);
       }
     }
+
+    searchOpDescription = "added to selection";
   }
   else if (_ui->selectionModeCombo->currentIndex() == 2) { // remove from current selection
     if (onNodes) {
@@ -365,29 +371,32 @@ void SearchWidget::search() {
         output->setEdgeValue(e,false);
       }
     }
+
+    searchOpDescription = "removed from selection";
   }
   else if (_ui->selectionModeCombo->currentIndex() == 3) { // no modification
     output = result;
+    searchOpDescription = "found but not added to selection";
   }
 
   if (deleteTermB)
     delete b;
 
   unsigned int resultsCountNodes = 0, resultsCountEdges=0;
-  forEach(n, output->getNodesEqualTo(true)) {
+  forEach(n, result->getNodesEqualTo(true)) {
     resultsCountNodes++;
   }
-  forEach(e, output->getEdgesEqualTo(true)) {
+  forEach(e, result->getEdgesEqualTo(true)) {
     resultsCountEdges++;
   }
   delete result;
 
   if(onNodes&&!onEdges)
-    _ui->resultsCountLabel->setText(QString::number(resultsCountNodes) + " node(s) found");
+    _ui->resultsCountLabel->setText(QString::number(resultsCountNodes) + " node(s) " + searchOpDescription);
   else if(!onNodes&&onEdges)
-    _ui->resultsCountLabel->setText(QString::number(resultsCountEdges) +" edge(s) found");
+    _ui->resultsCountLabel->setText(QString::number(resultsCountEdges) +" edge(s) " + searchOpDescription);
   else
-    _ui->resultsCountLabel->setText(QString::number(resultsCountNodes) + " node(s) and " +QString::number(resultsCountEdges) +" edge(s) found");
+    _ui->resultsCountLabel->setText(QString::number(resultsCountNodes) + " node(s) and " + QString::number(resultsCountEdges) +" edge(s) " + searchOpDescription);
 
   Observable::unholdObservers();
 }
