@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -29,6 +29,7 @@
 #include <tulip/GlTextureManager.h>
 #include <tulip/TulipViewSettings.h>
 
+#include <QPushButton>
 #include <QTextStream>
 #include <QTimeLine>
 #include <QMessageBox>
@@ -134,7 +135,7 @@ GlComposite *readPolyFile(QString fileName) {
     }
 
     if(lat==90.)
-      lat=89.999;
+      lat=89.999f;
 
     double mercatorLatitude=lat*2./360.*M_PI;
     mercatorLatitude=sin(abs(mercatorLatitude));
@@ -381,6 +382,8 @@ double mercatorToLatitude(double mercator) {
 }
 
 
+QGraphicsProxyWidget *proxyGM = NULL;
+
 GoogleMapsGraphicsView::GoogleMapsGraphicsView(GoogleMapsView *googleMapsView, QGraphicsScene *graphicsScene, QWidget *parent) :
   QGraphicsView(graphicsScene, parent),
   _googleMapsView(googleMapsView), graph(NULL), googleMaps(NULL),
@@ -410,7 +413,11 @@ GoogleMapsGraphicsView::GoogleMapsGraphicsView(GoogleMapsView *googleMapsView, Q
   googleMaps->setProgressWidget(progressWidget);
   googleMaps->setAdresseSelectionDialog(addressSelectionDialog,addresseSelectionProxy);
 
-  scene()->addWidget(googleMaps);
+  connect(googleMaps, SIGNAL(currentZoomChanged()),
+          _googleMapsView, SLOT(currentZoomChanged()));
+
+  QGraphicsProxyWidget *proxyGM = scene()->addWidget(googleMaps);
+  proxyGM->setPos(0,0);
 
   while (!googleMaps->pageInit()) {
     QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
@@ -425,18 +432,28 @@ GoogleMapsGraphicsView::GoogleMapsGraphicsView(GoogleMapsView *googleMapsView, Q
 
   scene()->addItem(glWidgetItem);
 
+  // combo box to choose the map type
   viewTypeComboBox=new QComboBox;
   viewTypeComboBox->addItems(QStringList()<<"RoadMap"<<"RoadMap"<<"Satellite" << "Terrain" << "Hybrid" <<"Polygon" << "Globe");
   viewTypeComboBox->insertSeparator(1);
-  QGraphicsProxyWidget *viewTypeProxyWidget=new QGraphicsProxyWidget;
-  viewTypeProxyWidget->setWidget(viewTypeComboBox);
-  viewTypeProxyWidget->setPos(20,20);
-  scene()->addItem(viewTypeProxyWidget);
+  scene()->addWidget(viewTypeComboBox)->setPos(20,20);
   connect(viewTypeComboBox,SIGNAL(currentIndexChanged(QString)),_googleMapsView,SLOT(viewTypeChanged(QString)));
+
+  // 2 push buttons
+  // zoom +
+  zoomInButton = new QPushButton(QIcon(":/zoom+.png"), "");
+  zoomInButton->setFixedSize(29, 27);
+  zoomInButton->setContentsMargins(0, 0, 0, 0);
+  connect(zoomInButton, SIGNAL(pressed()), _googleMapsView, SLOT(zoomIn()));
+  scene()->addWidget(zoomInButton)->setPos(20, 50);
+  // zoom -
+  zoomOutButton = new QPushButton(QIcon(":/zoom-.png"), "");
+  zoomOutButton->setFixedSize(29, 27);
+  zoomOutButton->setContentsMargins(0, 0, 0, 0);
+  connect(zoomOutButton, SIGNAL(pressed()), _googleMapsView, SLOT(zoomOut()));
+  scene()->addWidget(zoomOutButton)->setPos(20, 76);
 }
 
-
-
 GoogleMapsGraphicsView::~GoogleMapsGraphicsView() {
   if (geocodingActive) {
     if (addressSelectionDialog->isVisible()) {
@@ -623,12 +640,25 @@ void GoogleMapsGraphicsView::mapToPolygon() {
   delete nodesIt;
 }
 
+void GoogleMapsGraphicsView::zoomIn() {
+  googleMaps->setCurrentZoom(googleMaps->getCurrentMapZoom()+1);
+}
+
+void GoogleMapsGraphicsView::zoomOut() {
+  googleMaps->setCurrentZoom(googleMaps->getCurrentMapZoom()-1);
+}
+
+void GoogleMapsGraphicsView::currentZoomChanged() {
+  zoomInButton->setEnabled(googleMaps->getCurrentMapZoom() != 20);
+  zoomOutButton->setEnabled(googleMaps->getCurrentMapZoom() != 0);
+}
+
 GlGraphComposite *GoogleMapsGraphicsView::getGlGraphComposite() const {
   return glMainWidget->getScene()->getGlGraphComposite();
 
 }
 
-void GoogleMapsGraphicsView::createLayoutWithAddresses(string addressPropertyName, bool createLatAndLngProps) {
+void GoogleMapsGraphicsView::createLayoutWithAddresses(const string& addressPropertyName, bool createLatAndLngProps) {
   geocodingActive = true;
   nodeLatLng.clear();
   Observable::holdObservers();
@@ -703,7 +733,7 @@ void GoogleMapsGraphicsView::createLayoutWithAddresses(string addressPropertyNam
         }
         else {
           progressWidget->hide();
-          QMessageBox::warning(NULL, "Geolocalisation failed", "No results were found for address : \n" + QString::fromUtf8(addr.c_str()));
+          QMessageBox::warning(NULL, "Geolocation failed", "No results were found for address : \n" + QString::fromUtf8(addr.c_str()));
           progressWidget->show();
         }
 
@@ -761,7 +791,7 @@ void GoogleMapsGraphicsView::createLayoutWithAddresses(string addressPropertyNam
   geocodingActive = false;
 }
 
-void GoogleMapsGraphicsView::createLayoutWithLatLngs(std::string latitudePropertyName, std::string longitudePropertyName) {
+void GoogleMapsGraphicsView::createLayoutWithLatLngs(const std::string& latitudePropertyName, const std::string& longitudePropertyName) {
   nodeLatLng.clear();
   pair<double, double> latLng;
 
@@ -821,12 +851,17 @@ void GoogleMapsGraphicsView::paintEvent (QPaintEvent * event) {
       currentMapZoom = mapZoom;
 
       BoundingBox bb;
-      float mapWidth=(width()/(googleMaps->getPixelPosOnScreenForLatLng(180,180)-googleMaps->getPixelPosOnScreenForLatLng(0,0))[0])*180.;
-      float middleLng=googleMaps->getLatLngForPixelPosOnScreen(width()/2.,height()/2.).second*2.;
-      bb.expand(Coord(middleLng-mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(0,0).first*2.),0));
-      bb.expand(Coord(middleLng+mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(width(),height()).first*2.),0));
-      GlSceneZoomAndPan sceneZoomAndPan(glMainWidget->getScene(),bb,"Main",1);
-      sceneZoomAndPan.zoomAndPanAnimationStep(1);
+      Coord rightCoord = googleMaps->getPixelPosOnScreenForLatLng(180,180);
+      Coord leftCoord = googleMaps->getPixelPosOnScreenForLatLng(0,0);
+
+      if (rightCoord[0] - leftCoord[0]) {
+        float mapWidth=(width()/(rightCoord - leftCoord)[0])*180.;
+        float middleLng=googleMaps->getLatLngForPixelPosOnScreen(width()/2.,height()/2.).second*2.;
+        bb.expand(Coord(middleLng-mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(0,0).first*2.),0));
+        bb.expand(Coord(middleLng+mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(width(),height()).first*2.),0));
+        GlSceneZoomAndPan sceneZoomAndPan(glMainWidget->getScene(),bb,"Main",1);
+        sceneZoomAndPan.zoomAndPanAnimationStep(1);
+      }
     }
 
     glWidgetItem->setRedrawNeeded(true);
@@ -990,6 +1025,9 @@ void GoogleMapsGraphicsView::switchViewType() {
 
   GlLayer *layer=glMainWidget->getScene()->getLayer("Main");
 
+  if (geoLayout == graph->getProperty<LayoutProperty>("viewLayout"))
+    graph->push();
+
   Observable::holdObservers();
 
   if(switchToGoogleMap) {
@@ -1024,15 +1062,18 @@ void GoogleMapsGraphicsView::switchViewType() {
     node n;
 
     forEach(n, graph->getNodes()) {
-      const Size &nodeSize = viewSize->getNodeValue(n);
-      geoViewSize->setNodeValue(n, nodeSize);
+      if (viewSize != geoViewSize) {
+        const Size &nodeSize = viewSize->getNodeValue(n);
+        geoViewSize->setNodeValue(n, nodeSize);
+      }
 
       if (nodeLatLng.find(n) != nodeLatLng.end()) {
         geoLayout->setNodeValue(n, Coord(nodeLatLng[n].second*2., latitudeToMercator(nodeLatLng[n].first*2.),0));
       }
-      else {
+
+      /*else {
         geoLayout->setNodeValue(n, Coord(0,0,0));
-      }
+      }*/
     }
 
     if (edgeBendsLatLng.size() > 0) {
@@ -1049,15 +1090,19 @@ void GoogleMapsGraphicsView::switchViewType() {
     }
 
     BoundingBox bb;
-    float mapWidth=(width()/(googleMaps->getPixelPosOnScreenForLatLng(180,180)-googleMaps->getPixelPosOnScreenForLatLng(0,0))[0])*180.;
-    float middleLng=googleMaps->getLatLngForPixelPosOnScreen(width()/2.,height()/2.).second*2.;
-    bb.expand(Coord(middleLng-mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(0,0).first*2.),0));
-    bb.expand(Coord(middleLng+mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(width(),height()).first*2.),0));
-    GlSceneZoomAndPan sceneZoomAndPan(glMainWidget->getScene(),bb,"Main",1);
-    sceneZoomAndPan.zoomAndPanAnimationStep(1);
-  }
+    Coord rightCoord = googleMaps->getPixelPosOnScreenForLatLng(180,180);
+    Coord leftCoord = googleMaps->getPixelPosOnScreenForLatLng(0,0);
 
-  if(viewType==GoogleMapsView::Globe) {
+    if (rightCoord[0] - leftCoord[0]) {
+      float mapWidth=(width()/(rightCoord - leftCoord)[0])*180.;
+      float middleLng=googleMaps->getLatLngForPixelPosOnScreen(width()/2.,height()/2.).second*2.;
+      bb.expand(Coord(middleLng-mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(0,0).first*2.),0));
+      bb.expand(Coord(middleLng+mapWidth/2.,latitudeToMercator(googleMaps->getLatLngForPixelPosOnScreen(width(),height()).first*2.),0));
+      GlSceneZoomAndPan sceneZoomAndPan(glMainWidget->getScene(),bb,"Main",1);
+      sceneZoomAndPan.zoomAndPanAnimationStep(1);
+    }
+  }
+  else {
     SizeProperty *viewSize = graph->getProperty<SizeProperty>("viewSize");
     node n;
     edge e;
@@ -1070,8 +1115,10 @@ void GoogleMapsGraphicsView::switchViewType() {
     geoViewShape->setAllEdgeValue(EdgeShape::CubicBSplineCurve);
 
     forEach(n, graph->getNodes()) {
-      const Size &nodeSize = viewSize->getNodeValue(n);
-      geoViewSize->setNodeValue(n, nodeSize);
+      if (viewSize != geoViewSize) {
+        const Size &nodeSize = viewSize->getNodeValue(n);
+        geoViewSize->setNodeValue(n, nodeSize);
+      }
 
       if (nodeLatLng.find(n) != nodeLatLng.end()) {
         Coord tmp(nodeLatLng[n].first*2./360.*M_PI,nodeLatLng[n].second*2./360.*M_PI,0);
@@ -1091,9 +1138,10 @@ void GoogleMapsGraphicsView::switchViewType() {
                   50. * cos(phi));
         geoLayout->setNodeValue(n, tmp);
       }
-      else {
+
+      /*else {
         geoLayout->setNodeValue(n, Coord(0,0,0));
-      }
+      }*/
     }
 
     forEach(e, graph->getEdges()) {
