@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -457,13 +457,20 @@ void Histogram::createAxis() {
   }
   else {
     if (integerScale) {
-      int axisMin = (int) min;
-      int axisMax = (int) max;
-      int incrementStep = (int) ((max - min) / nbXGraduations);
+      long long axisMin = (long long) min;
+      long long axisMax = (long long) max;
 
-      if (incrementStep <1) incrementStep = 1;
+      // check the [min, max] double values range
+      // fit in a long long range
+      if (axisMax != LLONG_MIN) {
+        long long incrementStep = (long long) ((max - min) / nbXGraduations);
 
-      xAxis->setAxisParameters(axisMin, axisMax, incrementStep, GlAxis::LEFT_OR_BELOW, true);
+        if (incrementStep <1) incrementStep = 1;
+
+        xAxis->setAxisParameters(axisMin, axisMax, incrementStep, GlAxis::LEFT_OR_BELOW, true);
+      }
+      else
+        xAxis->setAxisParameters(min ,max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
     }
     else {
       xAxis->setAxisParameters(min ,max, nbXGraduations, GlAxis::LEFT_OR_BELOW, true);
