@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -703,6 +703,7 @@ void HistogramMetricMapping::initInteractor() {
   if (colorScaleConfigDialog == NULL) {
     colorScaleConfigDialog = new ColorScaleConfigDialog(colorScale, histoView->getGlMainWidget());
     *colorScale=colorScaleConfigDialog->getColorScale();
+    colorScale->setColorMapTransparency(200);
   }
 
   if (sizeScaleConfigDialog == NULL) {
@@ -1077,6 +1078,8 @@ bool HistogramMetricMapping::pointerUnderScale(const Coord &sceneCoords) {
 void HistogramMetricMapping::updateGraphWithMapping(Graph *graph, LayoutProperty *histogramLayout) {
 
   *colorScale=colorScaleConfigDialog->getColorScale();
+  colorScale->setColorMapTransparency(200);
+  glColorScale->setColorScale(colorScale);
 
   if ((mappingType == VIEWCOLOR_MAPPING || mappingType == VIEWBORDERCOLOR_MAPPING) && !colorScale->colorScaleInitialized()) {
     return;
