@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -71,7 +71,7 @@ HistogramView::HistogramView(const PluginContext *) :
   emptyGlGraphComposite(NULL), histogramsComposite(NULL), labelsComposite(NULL), axisComposite(NULL), smallMultiplesView(true), mainLayer(NULL), detailedHistogram(NULL),
   sceneRadiusBak(0), zoomFactorBak(0),
   noDimsLabel(NULL), noDimsLabel2(NULL), emptyRect(NULL), emptyRect2(NULL), lastViewWindowWidth(0),
-  lastViewWindowHeight(0), interactorsActivated(false), optionsMenu(NULL), centerViewAction(NULL), isConstruct(false), lastNbHistograms(0), dataLocation(NODE),needUpdateHistogram(false)  {
+  lastViewWindowHeight(0), interactorsActivated(false), isConstruct(false), lastNbHistograms(0), dataLocation(NODE),needUpdateHistogram(false)  {
   ++histoViewInstancesCount;
 }
 
@@ -176,10 +176,6 @@ void HistogramView::setState(const DataSet &dataSet) {
     histoOptionsWidget = new HistoOptionsWidget();
     propertiesSelectionWidget->setWidgetEnabled(true);
     histoOptionsWidget->setWidgetEnabled(false);
-    optionsMenu = new QMenu(tr("Options"));
-    centerViewAction = new QAction(tr("Center view"), this);
-    optionsMenu->addAction(centerViewAction);
-    connect(centerViewAction,SIGNAL(triggered()),this,SLOT(centerView()));
   }
 
   if (binTextureId == 0) {
@@ -324,12 +320,6 @@ DataSet HistogramView::state() const {
   return dataSet;
 }
 
-void HistogramView::fillContextMenu(QMenu *menu, const QPointF &point) {
-  menu->addAction(optionsMenu->menuAction());
-  menu->addSeparator();
-  GlMainView::fillContextMenu(menu,point);
-}
-
 bool HistogramView::eventFilter(QObject *object, QEvent *event) {
   if (xAxisDetail != NULL && event->type() == QEvent::ToolTip && !detailedHistogram->uniformQuantificationHistogram()) {
     QHelpEvent *he = static_cast<QHelpEvent *>(event);
@@ -388,10 +378,12 @@ void HistogramView::addEmptyViewLabel() {
 
 void HistogramView::removeEmptyViewLabel() {
   GlSimpleEntity *noDimsLabel = mainLayer->findGlEntity("no dimensions label");
+  GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
   GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
 
   if (noDimsLabel != NULL) {
     mainLayer->deleteGlEntity(noDimsLabel);
+    mainLayer->deleteGlEntity(noDimsLabel1);
     mainLayer->deleteGlEntity(noDimsLabel2);
   }
 }
@@ -508,8 +500,8 @@ void HistogramView::buildHistograms() {
     return;
   }
 
-  float spaceBetweenOverviews = OVERVIEW_SIZE / 10.;
-  float labelHeight = OVERVIEW_SIZE / 6;
+  float spaceBetweenOverviews = OVERVIEW_SIZE / 10.f;
+  float labelHeight = OVERVIEW_SIZE / 6.0f;
 
   float squareRoot = sqrt(double(selectedProperties.size()));
   const unsigned int N =  (unsigned int) squareRoot + (fmod((float) selectedProperties.size(), squareRoot) == 0. ? 0 : 1);
@@ -553,7 +545,7 @@ void HistogramView::buildHistograms() {
     histogramsComposite->addGlEntity(histogramsMap[selectedProperties[i]], oss.str());
 
     GlLabel *propertyLabel = new GlLabel(Coord(overviewBLCorner.getX() + OVERVIEW_SIZE / 2, overviewBLCorner.getY() - labelHeight / 2, 0),
-                                         Size((8./10.) * OVERVIEW_SIZE, labelHeight), foregroundColor);
+                                         Size((8.f/10.f) * OVERVIEW_SIZE, labelHeight), foregroundColor);
     propertyLabel->setText(selectedProperties[i]);
     propertiesLabels.push_back(propertyLabel);
 
@@ -569,11 +561,16 @@ void HistogramView::buildHistograms() {
     if (selectedProperties.size() == 1 || (detailedHistogramPropertyName == selectedProperties[i])) {
       detailedHistogram = histogramsMap[selectedProperties[i]];
     }
+
+    // add some feedback
+    if (i % 10 == 0)
+      QApplication::processEvents();
   }
 
   for(vector<GlLabel *>::iterator it=propertiesLabels.begin(); it!=propertiesLabels.end(); ++it) {
     (*it)->setSize(Size((*it)->getSize()[0],minSize));
   }
+
 }
 
 void HistogramView::updateHistograms(Histogram *detailOverview) {
