@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -131,8 +131,6 @@ public slots :
 
 protected slots :
 
-  void fillContextMenu(QMenu *menu, const QPointF &point);
-
 private :
 
   void interactorsInstalled(const QList<tlp::Interactor*>&);
@@ -179,9 +177,6 @@ private :
 
   bool interactorsActivated;
 
-  QMenu *optionsMenu;
-  QAction *centerViewAction;
-
   static GLuint binTextureId;
   static unsigned int histoViewInstancesCount;
 
