@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -387,16 +387,13 @@ void ParallelCoordinatesView::updateWithoutProgressBar() {
 
 void ParallelCoordinatesView::updateWithProgressBar() {
   if (parallelCoordsDrawing) {
-    //overviewWidget->setObservedView(NULL, NULL);
+    setOverviewVisible(false);
     toggleGraphView(glGraphComposite, false);
-    Interactor *currentInteractor = this->currentInteractor();
-    setCurrentInteractor(NULL);
     parallelCoordsDrawing->update(getGlMainWidget());
     toggleGraphView(glGraphComposite, true);
     centerView();
-    //overviewWidget->setObservedView(mainWidget, parallelCoordsDrawing);
-    setCurrentInteractor(currentInteractor);
     getGlMainWidget()->draw();
+    setOverviewVisible(true);
   }
 }
 
@@ -676,7 +673,8 @@ void ParallelCoordinatesView::setupAndDrawView() {
 
   registerTriggers();
   needDraw=true;
-  emit drawNeeded();
+  draw();
+  drawOverview(true);
 }
 
 ParallelCoordinatesDrawing::LayoutType ParallelCoordinatesView::getLayoutType() const {
