@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -644,9 +644,9 @@ void SOMView::computeMapping() {
   mappingTab.clear();
   algorithm.computeMapping(som, inputSample, mappingTab, medDist, maxSize);
 
-  float marginCoef = 0.1;
-  float spacingCoef = 0.2;
-  float minElementSizeCoef = 0.2;
+  float marginCoef = 0.1f;
+  float spacingCoef = 0.2f;
+  float minElementSizeCoef = 0.2f;
 
   SizeProperty *realGraphSizeProperty = graph()->getProperty<SizeProperty> ("viewSize");
 
