@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -28,6 +28,7 @@
 #include <QTime>
 #include <QMenu>
 #include <QGraphicsView>
+#include <QApplication>
 
 #include "ScatterPlot2DView.h"
 #include "ScatterPlot2DOptionsWidget.h"
@@ -206,7 +207,6 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
     Color backgroundColor;
     dataSet.get("background color", backgroundColor);
     optionsWidget->setBackgroundColor(backgroundColor);
-    emit drawNeeded();
     DataSet generatedScatterPlotDataSet;
     dataSet.get("generated scatter plots", generatedScatterPlotDataSet);
 
@@ -239,7 +239,7 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
       scatterPlotsGenMap[x_y] = true;
     }
 
-    switchFromMatrixToDetailView(scatterPlotsMap[make_pair(detailScatterPlotX, detailScatterPlotY)]);
+    switchFromMatrixToDetailView(scatterPlotsMap[make_pair(detailScatterPlotX, detailScatterPlotY)], true);
   }
 
   registerTriggers();
@@ -448,6 +448,10 @@ void ScatterPlot2DView::buildScatterPlotsMatrix() {
           matrixComposite->addGlEntity(scatterOverview, selectedGraphProperties[i] + "_" + selectedGraphProperties[j]);
           scatterOverview->setSizeProperty(scatterPlotSize);
         }
+
+        // add some feedback
+        /*if ((i + 1) * (j + 1) % 10 == 0)
+          QApplication::processEvents();*/
       }
     }
   }
@@ -456,7 +460,8 @@ void ScatterPlot2DView::buildScatterPlotsMatrix() {
     detailedScatterPlot = scatterPlotsMap[detailedScatterPlotPropertyName];
   }
 
-  centerView();
+  if (center)
+    centerView();
 }
 
 void ScatterPlot2DView::addEmptyViewLabel() {
@@ -535,7 +540,7 @@ void ScatterPlot2DView::draw() {
     matrixUpdateNeeded = true;
 
     if (newGraphSet) {
-      switchFromMatrixToDetailView(detailedScatterPlot);
+      switchFromMatrixToDetailView(detailedScatterPlot, center);
       newGraphSet = false;
     }
   }
@@ -550,7 +555,6 @@ void ScatterPlot2DView::draw() {
 
   if (center) {
     centerView();
-    center = false;
   }
   else {
     getGlMainWidget()->draw();
@@ -575,6 +579,7 @@ void ScatterPlot2DView::centerView(bool) {
   float glWidth = (float) graphicsView()->width();
   getGlMainWidget()->getScene()->zoomFactor((glWidth - 50)/ glWidth);
   getGlMainWidget()->draw();
+  center = false;
 }
 
 void ScatterPlot2DView::applySettings() {
@@ -676,16 +681,17 @@ void ScatterPlot2DView::generateScatterPlots() {
   Coord centerBak = getGlMainWidget()->getScene()->getGraphCamera().getCenter();
   Coord upBak = getGlMainWidget()->getScene()->getGraphCamera().getUp();
 
-  GlProgressBar *progressBar = new GlProgressBar(Coord(0.0f, 0.0f, 0.0f), 600.0f, 100.0f, Color(0,0,255));
+  GlProgressBar *progressBar =
+    new GlProgressBar(Coord(0.0f, 0.0f, 0.0f), 600.0f, 100.0f,
+                      // use same green color as the highlighting one
+                      // in workspace panel
+                      Color(0xCB, 0xDE, 0x5D));
   progressBar->setComment("Updating scatter plot matrix ...");
   progressBar->progress(currentStep, nbOverviews);
   mainLayer->addGlEntity(progressBar, "progress bar");
   centerView();
   getGlMainWidget()->draw();
 
-  QTime timer;
-  timer.start();
-
   for (size_t i = 0 ; i < selectedGraphProperties.size() - 1 ; ++i) {
     for (size_t j = 0 ; j < selectedGraphProperties.size() ; ++j) {
       ScatterPlot2D *overview = scatterPlotsMap[make_pair(selectedGraphProperties[i], selectedGraphProperties[j])];
@@ -696,22 +702,14 @@ void ScatterPlot2DView::generateScatterPlots() {
       overview->generateOverview();
       scatterPlotsGenMap[make_pair(selectedGraphProperties[i], selectedGraphProperties[j])] = true;
 
-      progressBar->progress(++currentStep, nbOverviews);
-      /*ScatterPlot2D *overviewReverse = scatterPlotsMap[make_pair(selectedGraphProperties[j], selectedGraphProperties[i])];
+      currentStep += 2;
+      progressBar->progress(currentStep, nbOverviews);
 
-      if (scatterPlotsGenMap[make_pair(selectedGraphProperties[i], selectedGraphProperties[j])]) {
-        overviewReverse->generateOverview(NULL, overview->getScatterPlotLayout());
-      } else {
-        overviewReverse->generateOverview();
-      }
-      scatterPlotsGenMap[make_pair(selectedGraphProperties[j], selectedGraphProperties[i])] = true;*/
-
-      progressBar->progress(++currentStep, nbOverviews);
-
-      if (timer.elapsed() >= 50) {
+      // needed to display progressBar
+      if ((i + 1) * (j + 1) % 10 == 0)
         getGlMainWidget()->draw();
-        timer.start();
-      }
+
+      QApplication::processEvents();
     }
   }
 
@@ -747,7 +745,7 @@ void ScatterPlot2DView::generateScatterPlot(ScatterPlot2D *scatterPlot, GlMainWi
   scatterPlotsGenMap[make_pair(scatterPlot->getXDim(), scatterPlot->getYDim())] = true;
 }
 
-void ScatterPlot2DView::switchFromMatrixToDetailView(ScatterPlot2D *scatterPlot) {
+void ScatterPlot2DView::switchFromMatrixToDetailView(ScatterPlot2D *scatterPlot, bool recenter) {
 
   sceneRadiusBak = getGlMainWidget()->getScene()->getGraphCamera().getSceneRadius();
   zoomFactorBak = getGlMainWidget()->getScene()->getGraphCamera().getZoomFactor();
@@ -773,7 +771,9 @@ void ScatterPlot2DView::switchFromMatrixToDetailView(ScatterPlot2D *scatterPlot)
   detailedScatterPlot = scatterPlot;
   detailedScatterPlotPropertyName = make_pair(scatterPlot->getXDim(), scatterPlot->getYDim());
   propertiesSelectionWidget->setEnabled(false);
-  centerView();
+
+  if (recenter)
+    centerView();
 }
 
 void ScatterPlot2DView::switchFromDetailViewToMatrixView() {
