@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -407,6 +407,13 @@ void PropertiesEditor::setPropertyChecked(int index, bool state) {
   _sourceModel->setData(_sourceModel->index(index,0),state ? Qt::Checked : Qt::Unchecked,Qt::CheckStateRole);
 }
 
+void PropertiesEditor::setPropertyChecked(const QString& pName, bool state) {
+  int index = _sourceModel->rowOf(pName);
+
+  if (index != -1)
+    _sourceModel->setData(_sourceModel->index(index,0),state ? Qt::Checked : Qt::Unchecked,Qt::CheckStateRole);
+}
+
 PropertyInterface *PropertiesEditor::contextProperty() const {
   return _contextProperty;
 }
