@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -167,8 +167,12 @@ QList<QWidget*> TableView::configurationWidgets() const {
 void TableView::graphChanged(tlp::Graph* g) {
   isNewGraph = true;
   QSet<QString> visibleProperties;
-  foreach(tlp::PropertyInterface* pi, propertiesEditor->visibleProperties()) {
-    visibleProperties.insert(QString::fromUtf8(pi->getName().c_str()));
+
+  if (g && propertiesEditor->getGraph() &&
+      (g->getRoot() == propertiesEditor->getGraph()->getRoot())) {
+    foreach(tlp::PropertyInterface* pi, propertiesEditor->visibleProperties()) {
+      visibleProperties.insert(QString::fromUtf8(pi->getName().c_str()));
+    }
   }
 
   GraphPropertiesModel<BooleanProperty>* model = new GraphPropertiesModel<BooleanProperty>(trUtf8("no selection"),g,false,_ui->filteringPropertyCombo);
@@ -184,13 +188,10 @@ void TableView::graphChanged(tlp::Graph* g) {
   if (_model != NULL) {
     for(int i=0; i < _model->columnCount(); ++i) {
       QString propName = _model->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString();
-      bool checked = true;
+      bool checked = !visibleProperties.isEmpty() ?
+                     visibleProperties.contains(propName) : true;
 
-      if (!visibleProperties.isEmpty()) {
-        checked = visibleProperties.contains(propName);
-      }
-
-      propertiesEditor->setPropertyChecked(i, checked);
+      propertiesEditor->setPropertyChecked(propName, checked);
     }
   }
 
@@ -662,8 +663,6 @@ void TableView::showHorizontalHeaderCustomContextMenu(const QPoint & pos) {
   if (!Perspective::instance()->isReservedPropertyName(propName.c_str()))
     renameProp = contextMenu.addAction("Rename");
 
-  contextMenu.addSeparator();
-
   QMenu* subMenu = contextMenu.addMenu(trUtf8("Set values of "));
   QAction* nodesSetAll = subMenu->addAction(trUtf8("All nodes"));
   QAction* edgesSetAll = subMenu->addAction(trUtf8("All edges"));
@@ -695,6 +694,10 @@ void TableView::showHorizontalHeaderCustomContextMenu(const QPoint & pos) {
       highlightedToLabels = subMenu->addAction((trUtf8("Rows highlighted") + ' ' + eltsName) + (highlightedRows.size() > 1 ? "" : QString(NODES_DISPLAYED ? " (Node #%1)" : " (Edge #%1)").arg(highlightedRows[0].data(TulipModel::ElementIdRole).toUInt())));
   }
 
+  contextMenu.addSeparator();
+  QAction* sortById = contextMenu.addAction("Sort by id");
+  contextMenu.addSeparator();
+
   // display the menu with the mouse inside to allow
   // keyboard navigation
   action = contextMenu.exec(QCursor::pos() - QPoint(5,5));
@@ -702,6 +705,29 @@ void TableView::showHorizontalHeaderCustomContextMenu(const QPoint & pos) {
   if (!action)
     return;
 
+  if (action == sortById) {
+    if (_ui->table->horizontalHeader()->sortIndicatorSection() != -1) {
+      _ui->table->horizontalHeader()->setSortIndicator(-1, Qt::AscendingOrder);
+      GraphSortFilterProxyModel* sortModel = static_cast<GraphSortFilterProxyModel*>(_ui->table->model());
+      QAbstractItemModel* model = sortModel->sourceModel();
+      sortModel->setSourceModel(NULL);
+      sortModel->setSourceModel(model);
+      sortModel->setFilterProperty(getFilteringProperty());
+
+      QSet<tlp::PropertyInterface*> visibleProperties = propertiesEditor->visibleProperties();
+
+      for (int i=0; i <model->columnCount(); ++i) {
+        PropertyInterface* pi =
+          _model->headerData(i, Qt::Horizontal, TulipModel::PropertyRole).value<tlp::PropertyInterface*>();
+
+        if (!visibleProperties.contains(pi))
+          _ui->table->setColumnHidden(i, true);
+      }
+    }
+
+    return;
+  }
+
   // hold/unhold observers
   tlp::ObserverHolder oh;
 
