@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -39,6 +39,7 @@
 #include <tulip/PluginManager.h>
 #include <tulip/QuaZIPFacade.h>
 #include <tulip/TlpQtTools.h>
+#include <tulip/PythonVersionChecker.h>
 
 #include <CrashHandling.h>
 
@@ -55,6 +56,10 @@
 #include <signal.h>
 #endif
 
+#ifdef WIN32
+#include <windows.h>
+#endif
+
 #ifdef interface
 #undef interface
 #endif
@@ -97,6 +102,9 @@ void checkTulipRunning(const QString& perspName, const QString& fileToOpen) {
     int n_agentPort = agentPort.toInt(&ok);
 
     if (ok && sendAgentMessage(n_agentPort,"SHOW_AGENT\tPROJECTS")) {
+
+      QMessageBox::warning(NULL, "Warning", "An instance of Tulip agent is already running,\ndisplaying it...");
+
       // if a file was passed as argument, forward it to the running instance
       if (!fileToOpen.isNull()) { // open the file passed as argument
         if (!perspName.isNull()) {
@@ -121,8 +129,6 @@ void checkTulipRunning(const QString& perspName, const QString& fileToOpen) {
 int main(int argc, char **argv) {
   start_crash_handler();
 
-
-
   QApplication tulip_agent(argc, argv);
   QString name("Tulip ");
 
@@ -142,6 +148,20 @@ int main(int argc, char **argv) {
   QApplication::addLibraryPath(QApplication::applicationDirPath() + "/..");
 #endif
 
+#ifdef WIN32
+  // MS stated that SetDllDirectory only exists since WinXP SP1
+#if (_WIN32_WINNT >= 0x0502)
+
+  // Python on windows can be installed for current user only.
+  // In that case, the Python dll is not located in system path but in the Python home directory.
+  // So add the Python home directory in the Dll search paths in order to be able to load plugins depending on Python.
+  if (tlp::PythonVersionChecker::isPythonVersionMatching()) {
+    SetDllDirectory(tlp::PythonVersionChecker::getPythonHome().toStdString().c_str());
+  }
+
+#endif
+#endif
+
   // Parse arguments
   QRegExp perspectiveRegexp("^\\-\\-perspective=(.*)");
   QString perspName;
