@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -21,6 +21,7 @@
 #include <QApplication>
 #include <QMainWindow>
 #include <QMessageBox>
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QStandardPaths>
 #else
@@ -49,11 +50,16 @@
 #include <tulip/View.h>
 #include <tulip/GlMainView.h>
 #include <tulip/GlMainWidget.h>
+#include <tulip/PythonVersionChecker.h>
 
 #include "TulipPerspectiveMainWindow.h"
 
 #include <iostream>
 
+#ifdef WIN32
+#include <windows.h>
+#endif
+
 #ifdef interface
 #undef interface
 #endif
@@ -151,6 +157,20 @@ int main(int argc,char **argv) {
   QApplication::addLibraryPath(QApplication::applicationDirPath() + "/..");
 #endif
 
+#ifdef WIN32
+  // MS stated that SetDllDirectory only exists since WinXP SP1
+#if (_WIN32_WINNT >= 0x0502)
+
+  // Python on windows can be installed for current user only.
+  // In that case, the Python dll is not located in system path but in the Python home directory.
+  // So add the Python home directory in the Dll search paths in order to be able to load plugins depending on Python.
+  if (PythonVersionChecker::isPythonVersionMatching()) {
+    SetDllDirectory(PythonVersionChecker::getPythonHome().toStdString().c_str());
+  }
+
+#endif
+#endif
+
   // Check arguments
   QString perspectiveName,projectFilePath;
   QVariantMap extraParams;
@@ -217,7 +237,7 @@ int main(int argc,char **argv) {
   }
 
   // Create perspective's window
-  TulipPerspectiveProcessMainWindow *mainWindow = new TulipPerspectiveProcessMainWindow();
+  TulipPerspectiveProcessMainWindow *mainWindow = new TulipPerspectiveProcessMainWindow(title);
   mainWindow->setVisible(false);
 
   // Progress bar dialog
@@ -230,6 +250,8 @@ int main(int argc,char **argv) {
   progress->setWindowTitle(title);
   progress->progress(0,100);
 
+
+
   initTulipLib(QApplication::applicationDirPath().toUtf8().data());
   QIcon icon = progress->windowIcon();
 
@@ -310,26 +332,11 @@ int main(int argc,char **argv) {
   }
 
   Perspective::setInstance(perspective);
-  mainWindow->setPerspective(perspective);
-
-  title += QString(" [") + perspectiveName + "]";
-
-  if (project) {
-    if (!project->name().isEmpty())
-      title += QString(" - ") + project->name();
-    else if (!projectFilePath.isEmpty())
-      title += QString(" - ") + projectFilePath;
-  }
-
-#ifndef NDEBUG
-  title += " - [ Debug mode ]";
-#endif
+  mainWindow->setProject(project);
 
   perspective->start(progress);
 
-  if (mainWindow->windowTitle() == "") {
-    mainWindow->setWindowTitle(title);
-  }
+  mainWindow->projectFileChanged(projectFilePath);
 
   delete progress;
 
