@@ -79,31 +79,30 @@ double OGDF_clk_tck = sysconf(_SC_CLK_TCK); //is long. but definig it here avoid
 
 
 #ifdef OGDF_DLL
-extern "C" {
+
 #ifdef OGDF_SYSTEM_WINDOWS
 
 #ifdef __MINGW32__
 extern "C"
 #endif
 BOOL APIENTRY DllMain(HANDLE hModule, DWORD  ul_reason_for_call, LPVOID lpReserved)
-    {
+{
 	switch (ul_reason_for_call)
-        {
-	case DLL_PROCESS_ATTACH:
-		ogdf::PoolMemoryAllocator::init();
-		ogdf::System::init();
-		break;
+  {
+    case DLL_PROCESS_ATTACH:
+      ogdf::PoolMemoryAllocator::init();
+      ogdf::System::init();
+      break;
 
-	case DLL_THREAD_ATTACH:
-	case DLL_THREAD_DETACH:
-		break;
+    case DLL_THREAD_ATTACH:
+    case DLL_THREAD_DETACH:
+      break;
 
-	case DLL_PROCESS_DETACH:
-		ogdf::PoolMemoryAllocator::cleanup();
-		break;
+    case DLL_PROCESS_DETACH:
+      ogdf::PoolMemoryAllocator::cleanup();
+      break;
 	}
 	return TRUE;
-    }
 }
 #else
 void __attribute__ ((constructor)) my_load(void)
